<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('client_reminder');

// 记录访问日志
record_log('访问客户提醒页面');

// 添加/编辑提醒处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 这里可以实现对提醒的添加、编辑和删除操作
    // 但目前我们专注于展示提醒功能
}

// 获取当前日期
$current_date = date('Y-m-d');
$next_month_date = date('Y-m-d', strtotime('+30 days'));

// 获取联系人生日提醒
try {
    // 查询最近30天内过生日的联系人
    $stmt = $pdo->prepare("
        SELECT c.id, c.name, c.birthday, cl.client_name, cl.owner_user_id, u.username as owner_name
        FROM crm_contacts c 
        JOIN crm_clients cl ON c.client_id = cl.id
        LEFT JOIN sys_users u ON cl.owner_user_id = u.id
        WHERE 
            c.birthday IS NOT NULL 
            AND (
                (DATE_FORMAT(c.birthday, '%m-%d') >= DATE_FORMAT(NOW(), '%m-%d'))
                AND 
                (DATE_FORMAT(c.birthday, '%m-%d') <= DATE_FORMAT(DATE_ADD(NOW(), INTERVAL 30 DAY), '%m-%d'))
            )
        ORDER BY DATE_FORMAT(c.birthday, '%m-%d')
    ");
    $stmt->execute();
    $birthday_reminders = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取生日提醒失败：' . $e->getMessage();
    $birthday_reminders = [];
}

// 获取合同到期提醒
try {
    // 查询30天内到期的合同
    $stmt = $pdo->prepare("
        SELECT c.id, c.contract_no, c.client_id, c.start_date, c.end_date, cl.client_name, cl.owner_user_id, u.username as owner_name
        FROM sales_contracts c 
        JOIN crm_clients cl ON c.client_id = cl.id
        LEFT JOIN sys_users u ON cl.owner_user_id = u.id
        WHERE 
            c.status = 3 
            AND c.end_date BETWEEN CURRENT_DATE() AND DATE_ADD(CURRENT_DATE(), INTERVAL 30 DAY)
        ORDER BY c.end_date ASC
    ");
    $stmt->execute();
    $contract_reminders = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取合同到期提醒失败：' . $e->getMessage();
    $contract_reminders = [];
}

// 获取回访提醒（最近互动超过30天的客户）
try {
    $stmt = $pdo->prepare("
        SELECT 
            c.id, 
            c.client_name, 
            c.owner_user_id,
            u.username as owner_name,
            MAX(i.interaction_time) as last_interaction_time,
            DATEDIFF(CURRENT_DATE(), MAX(i.interaction_time)) as days_since_last_interaction
        FROM 
            crm_clients c
        LEFT JOIN 
            crm_interactions i ON c.id = i.client_id
        LEFT JOIN 
            sys_users u ON c.owner_user_id = u.id
        GROUP BY 
            c.id
        HAVING 
            days_since_last_interaction >= 30 OR days_since_last_interaction IS NULL
        ORDER BY 
            last_interaction_time ASC, c.client_name ASC
    ");
    $stmt->execute();
    $followup_reminders = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取回访提醒失败：' . $e->getMessage();
    $followup_reminders = [];
}

// 计算各类提醒的总数
$total_reminders = count($birthday_reminders) + count($contract_reminders) + count($followup_reminders);
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>客户提醒</h2>
            <div class="breadcrumb">
                <a href="index.php">客户管理</a> &gt; 客户提醒
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div>
                <h3>提醒概览 (共<?php echo $total_reminders; ?>条)</h3>
                <div class="dashboard">
                    <div class="dashboard-card">
                        <h3>生日提醒</h3>
                        <div class="number"><?php echo count($birthday_reminders); ?></div>
                        <div class="desc">30天内</div>
                    </div>
                    <div class="dashboard-card">
                        <h3>合同到期</h3>
                        <div class="number"><?php echo count($contract_reminders); ?></div>
                        <div class="desc">30天内</div>
                    </div>
                    <div class="dashboard-card">
                        <h3>回访提醒</h3>
                        <div class="number"><?php echo count($followup_reminders); ?></div>
                        <div class="desc">30天以上未互动</div>
                    </div>
                </div>
            </div>

            <!-- 生日提醒 -->
            <div class="table-container">
                <h3>联系人生日提醒 (30天内)</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>联系人</th>
                            <th>所属客户</th>
                            <th>生日日期</th>
                            <th>距离天数</th>
                            <th>负责人</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($birthday_reminders)): ?>
                            <tr>
                                <td colspan="6" class="text-center">暂无生日提醒</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($birthday_reminders as $reminder): ?>
                                <?php
                                // 计算今年的生日日期
                                $birthday = $reminder['birthday'];
                                $birthday_month_day = date('m-d', strtotime($birthday));
                                $this_year_birthday = date('Y') . '-' . $birthday_month_day;

                                // 如果今年的生日已经过了，则计算明年的生日
                                if (strtotime($this_year_birthday) < strtotime($current_date)) {
                                    $this_year_birthday = (date('Y') + 1) . '-' . $birthday_month_day;
                                }

                                // 计算距离天数
                                $days_until = floor((strtotime($this_year_birthday) - strtotime($current_date)) / (60 * 60 * 24));
                                ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($reminder['name']); ?></td>
                                    <td><?php echo htmlspecialchars($reminder['client_name']); ?></td>
                                    <td><?php echo date('Y-m-d', strtotime($birthday)); ?></td>
                                    <td><?php echo $days_until; ?>天</td>
                                    <td><?php echo htmlspecialchars($reminder['owner_name']); ?></td>
                                    <td>
                                        <a href="contact.php?action=edit&id=<?php echo $reminder['id']; ?>" class="btn btn-sm btn-edit">联系人详情</a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 合同到期提醒 -->
            <div class="table-container">
                <h3>合同到期提醒 (30天内)</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>合同编号</th>
                            <th>客户名称</th>
                            <th>开始日期</th>
                            <th>结束日期</th>
                            <th>剩余天数</th>
                            <th>负责人</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($contract_reminders)): ?>
                            <tr>
                                <td colspan="7" class="text-center">暂无合同到期提醒</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($contract_reminders as $reminder): ?>
                                <?php
                                // 计算距离到期天数
                                $days_until = floor((strtotime($reminder['end_date']) - strtotime($current_date)) / (60 * 60 * 24));
                                ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($reminder['contract_no']); ?></td>
                                    <td><?php echo htmlspecialchars($reminder['client_name']); ?></td>
                                    <td><?php echo $reminder['start_date']; ?></td>
                                    <td><?php echo $reminder['end_date']; ?></td>
                                    <td><?php echo $days_until; ?>天</td>
                                    <td><?php echo htmlspecialchars($reminder['owner_name']); ?></td>
                                    <td>
                                        <a href="../sales/contract.php?action=edit&id=<?php echo $reminder['id']; ?>" class="btn btn-sm btn-edit">合同详情</a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 回访提醒 -->
            <div class="table-container">
                <h3>回访提醒 (30天以上未互动)</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>客户名称</th>
                            <th>最后互动时间</th>
                            <th>未互动天数</th>
                            <th>负责人</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($followup_reminders)): ?>
                            <tr>
                                <td colspan="5" class="text-center">暂无回访提醒</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($followup_reminders as $reminder): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($reminder['client_name']); ?></td>
                                    <td><?php echo $reminder['last_interaction_time'] ? date('Y-m-d', strtotime($reminder['last_interaction_time'])) : '从未互动'; ?></td>
                                    <td><?php echo $reminder['days_since_last_interaction'] ? $reminder['days_since_last_interaction'] . '天' : '从未互动'; ?></td>
                                    <td><?php echo htmlspecialchars($reminder['owner_name']); ?></td>
                                    <td>
                                        <a href="relation.php?action=add&client_id=<?php echo $reminder['id']; ?>" class="btn btn-sm btn-add">添加互动</a>
                                        <a href="profile.php?action=edit&id=<?php echo $reminder['id']; ?>" class="btn btn-sm btn-edit">客户详情</a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>