<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('marketing_analysis');

// 记录访问日志
record_log('访问营销数据分析页面');

// 获取时间段参数
$period = isset($_GET['period']) ? $_GET['period'] : 'month';
$channel_type = isset($_GET['channel_type']) ? intval($_GET['channel_type']) : 0;

// 根据选择的时间段设置查询日期范围
$start_date = '';
$end_date = date('Y-m-d');
$period_name = '';

switch ($period) {
    case 'week':
        $start_date = date('Y-m-d', strtotime('-7 days'));
        $period_name = '最近7天';
        break;
    case 'month':
        $start_date = date('Y-m-01');
        $period_name = '本月';
        break;
    case 'lastmonth':
        $start_date = date('Y-m-01', strtotime('-1 month'));
        $end_date = date('Y-m-t', strtotime('-1 month'));
        $period_name = '上月';
        break;
    case 'quarter':
        $current_month = date('n');
        $current_quarter = ceil($current_month / 3);
        $start_date = date('Y-' . (($current_quarter - 1) * 3 + 1) . '-01');
        $period_name = '本季度';
        break;
    case 'year':
        $start_date = date('Y-01-01');
        $period_name = '本年度';
        break;
    case 'custom':
        $start_date = isset($_GET['start_date']) ? $_GET['start_date'] : date('Y-m-d', strtotime('-30 days'));
        $end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d');
        $period_name = $start_date . ' 至 ' . $end_date;
        break;
    default:
        $start_date = date('Y-m-01');
        $period_name = '本月';
}

// 获取渠道类型
try {
    $stmt = $pdo->query("SELECT DISTINCT type FROM mkt_channels ORDER BY type");
    $channel_types = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取渠道类型失败：' . $e->getMessage();
    $channel_types = [];
}

// 构建渠道类型查询条件
$channel_type_condition = '';
if ($channel_type > 0) {
    $channel_type_condition = " AND ch.type = {$channel_type} ";
}

// 营销活动总体效果
try {
    $stmt = $pdo->prepare("
        SELECT 
            COUNT(DISTINCT c.id) as campaign_count,
            COUNT(DISTINCT ch.id) as channel_count,
            SUM(r.reach) as total_reach,
            SUM(r.click) as total_click,
            SUM(r.conversion) as total_conversion,
            SUM(r.cost) as total_cost,
            SUM(r.revenue) as total_revenue,
            ROUND(AVG(r.roi), 2) as avg_roi
        FROM mkt_campaigns c
        JOIN mkt_channels ch ON c.id = ch.campaign_id
        LEFT JOIN mkt_results r ON ch.id = r.channel_id
        WHERE (c.start_date BETWEEN ? AND ? OR c.end_date BETWEEN ? AND ?)
              {$channel_type_condition}
    ");
    $stmt->execute([$start_date, $end_date, $start_date, $end_date]);
    $overall_stats = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取营销活动总体数据失败：' . $e->getMessage();
    $overall_stats = [
        'campaign_count' => 0,
        'channel_count' => 0,
        'total_reach' => 0,
        'total_click' => 0,
        'total_conversion' => 0,
        'total_cost' => 0,
        'total_revenue' => 0,
        'avg_roi' => 0
    ];
}

// 计算转化率和点击率
$overall_stats['conversion_rate'] = $overall_stats['total_click'] > 0 ?
    round(($overall_stats['total_conversion'] / $overall_stats['total_click']) * 100, 2) : 0;
$overall_stats['click_rate'] = $overall_stats['total_reach'] > 0 ?
    round(($overall_stats['total_click'] / $overall_stats['total_reach']) * 100, 2) : 0;

// 活动效果排行（按ROI降序）
try {
    $stmt = $pdo->prepare("
        SELECT 
            c.id, c.name, c.type,
            SUM(r.reach) as reach,
            SUM(r.click) as click,
            SUM(r.conversion) as conversion,
            SUM(r.cost) as cost,
            SUM(r.revenue) as revenue,
            ROUND(AVG(r.roi), 2) as roi
        FROM mkt_campaigns c
        JOIN mkt_channels ch ON c.id = ch.campaign_id
        LEFT JOIN mkt_results r ON ch.id = r.channel_id
        WHERE (c.start_date BETWEEN ? AND ? OR c.end_date BETWEEN ? AND ?)
              {$channel_type_condition}
        GROUP BY c.id
        ORDER BY roi DESC
        LIMIT 10
    ");
    $stmt->execute([$start_date, $end_date, $start_date, $end_date]);
    $top_campaigns = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取活动效果排行数据失败：' . $e->getMessage();
    $top_campaigns = [];
}

// 渠道效果分析
try {
    $stmt = $pdo->prepare("
        SELECT 
            CASE ch.type
                WHEN 1 THEN '邮件'
                WHEN 2 THEN '短信'
                WHEN 3 THEN '社交媒体'
                WHEN 4 THEN '搜索引擎'
                WHEN 5 THEN '抖音'
                ELSE '其他'
            END as channel_name,
            COUNT(DISTINCT ch.id) as channel_count,
            SUM(r.reach) as reach,
            SUM(r.click) as click,
            SUM(r.conversion) as conversion,
            SUM(r.cost) as cost,
            SUM(r.revenue) as revenue,
            ROUND(AVG(r.roi), 2) as roi
        FROM mkt_channels ch
        JOIN mkt_campaigns c ON ch.campaign_id = c.id
        LEFT JOIN mkt_results r ON ch.id = r.channel_id
        WHERE (c.start_date BETWEEN ? AND ? OR c.end_date BETWEEN ? AND ?)
        GROUP BY ch.type
        ORDER BY roi DESC
    ");
    $stmt->execute([$start_date, $end_date, $start_date, $end_date]);
    $channel_stats = $stmt->fetchAll();

    // 计算总花费，用于计算百分比
    $total_cost = 0;
    foreach ($channel_stats as $stat) {
        $total_cost += $stat['cost'];
    }
} catch (PDOException $e) {
    $error = '获取渠道效果分析数据失败：' . $e->getMessage();
    $channel_stats = [];
    $total_cost = 0;
}

// 最高转化渠道TOP5
try {
    $stmt = $pdo->prepare("
        SELECT 
            ch.id, ch.name, 
            CASE ch.type
                WHEN 1 THEN '邮件'
                WHEN 2 THEN '短信'
                WHEN 3 THEN '社交媒体'
                WHEN 4 THEN '搜索引擎'
                WHEN 5 THEN '抖音'
                ELSE '其他'
            END as channel_type,
            c.name as campaign_name,
            r.reach, r.click, r.conversion,
            ROUND((r.conversion / r.click) * 100, 2) as conversion_rate
        FROM mkt_channels ch
        JOIN mkt_campaigns c ON ch.campaign_id = c.id
        JOIN mkt_results r ON ch.id = r.channel_id
        WHERE (c.start_date BETWEEN ? AND ? OR c.end_date BETWEEN ? AND ?)
              AND r.click > 0
              {$channel_type_condition}
        ORDER BY conversion_rate DESC
        LIMIT 5
    ");
    $stmt->execute([$start_date, $end_date, $start_date, $end_date]);
    $top_conversion_channels = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取最高转化渠道数据失败：' . $e->getMessage();
    $top_conversion_channels = [];
}

// 营销效果趋势（最近6个月）
try {
    $months = [];
    $month_stats = [];

    for ($i = 5; $i >= 0; $i--) {
        $month_start = date('Y-m-01', strtotime("-{$i} month"));
        $month_end = date('Y-m-t', strtotime("-{$i} month"));
        $month_name = date('Y年m月', strtotime("-{$i} month"));

        $stmt = $pdo->prepare("
            SELECT 
                SUM(r.reach) as reach,
                SUM(r.click) as click,
                SUM(r.conversion) as conversion,
                SUM(r.cost) as cost,
                SUM(r.revenue) as revenue,
                ROUND(AVG(r.roi), 2) as roi
            FROM mkt_results r
            JOIN mkt_channels ch ON r.channel_id = ch.id
            JOIN mkt_campaigns c ON r.campaign_id = c.id
            WHERE c.start_date <= ? AND c.end_date >= ?
                  {$channel_type_condition}
        ");
        $stmt->execute([$month_end, $month_start]);
        $result = $stmt->fetch();

        $months[] = $month_name;
        $month_stats[$month_name] = [
            'reach' => $result['reach'] ?: 0,
            'click' => $result['click'] ?: 0,
            'conversion' => $result['conversion'] ?: 0,
            'roi' => $result['roi'] ?: 0
        ];
    }
} catch (PDOException $e) {
    $error = '获取营销效果趋势数据失败：' . $e->getMessage();
    $months = [];
    $month_stats = [];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>营销数据分析</h2>
            <div class="breadcrumb">
                <a href="index.php">市场营销管理</a> &gt; 营销数据分析
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <!-- 筛选条件 -->
            <div class="filter-form">
                <form method="get" action="">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="period">时间段：</label>
                            <select id="period" name="period" onchange="this.form.submit()">
                                <option value="week" <?php echo $period == 'week' ? 'selected' : ''; ?>>最近7天</option>
                                <option value="month" <?php echo $period == 'month' ? 'selected' : ''; ?>>本月</option>
                                <option value="lastmonth" <?php echo $period == 'lastmonth' ? 'selected' : ''; ?>>上月</option>
                                <option value="quarter" <?php echo $period == 'quarter' ? 'selected' : ''; ?>>本季度</option>
                                <option value="year" <?php echo $period == 'year' ? 'selected' : ''; ?>>本年度</option>
                                <option value="custom" <?php echo $period == 'custom' ? 'selected' : ''; ?>>自定义时间段</option>
                            </select>
                        </div>

                        <div class="filter-item">
                            <label for="channel_type">渠道类型：</label>
                            <select id="channel_type" name="channel_type" onchange="this.form.submit()">
                                <option value="0">所有渠道</option>
                                <option value="1" <?php echo $channel_type == 1 ? 'selected' : ''; ?>>邮件</option>
                                <option value="2" <?php echo $channel_type == 2 ? 'selected' : ''; ?>>短信</option>
                                <option value="3" <?php echo $channel_type == 3 ? 'selected' : ''; ?>>社交媒体</option>
                                <option value="4" <?php echo $channel_type == 4 ? 'selected' : ''; ?>>搜索引擎</option>
                                <option value="5" <?php echo $channel_type == 5 ? 'selected' : ''; ?>>抖音</option>
                            </select>
                        </div>

                        <?php if ($period == 'custom'): ?>
                            <div class="filter-item">
                                <label for="start_date">开始日期：</label>
                                <input type="date" id="start_date" name="start_date" value="<?php echo $start_date; ?>">
                            </div>

                            <div class="filter-item">
                                <label for="end_date">结束日期：</label>
                                <input type="date" id="end_date" name="end_date" value="<?php echo $end_date; ?>">
                            </div>

                            <div class="filter-item">
                                <label>&nbsp;</label>
                                <button type="submit" class="btn btn-primary">筛选</button>
                            </div>
                        <?php endif; ?>
                    </div>
                </form>
            </div>

            <!-- 营销概览 -->
            <div>
                <h3>营销概览 - <?php echo $period_name; ?></h3>
                <div class="dashboard">
                    <div class="dashboard-card">
                        <h3>活动数量</h3>
                        <div class="number"><?php echo number_format($overall_stats['campaign_count']); ?></div>
                        <div class="desc">个</div>
                    </div>

                    <div class="dashboard-card">
                        <h3>触达人数</h3>
                        <div class="number"><?php echo number_format($overall_stats['total_reach']); ?></div>
                        <div class="desc">人</div>
                    </div>

                    <div class="dashboard-card">
                        <h3>转化次数</h3>
                        <div class="number"><?php echo number_format($overall_stats['total_conversion']); ?></div>
                        <div class="desc">次</div>
                    </div>

                    <div class="dashboard-card">
                        <h3>平均ROI</h3>
                        <div class="number"><?php echo number_format($overall_stats['avg_roi'], 2); ?></div>
                        <div class="desc">%</div>
                    </div>
                </div>

                <div class="dashboard">
                    <div class="dashboard-card">
                        <h3>总花费</h3>
                        <div class="number"><?php echo number_format($overall_stats['total_cost'], 2); ?></div>
                        <div class="desc">元</div>
                    </div>

                    <div class="dashboard-card">
                        <h3>总收入</h3>
                        <div class="number"><?php echo number_format($overall_stats['total_revenue'], 2); ?></div>
                        <div class="desc">元</div>
                    </div>

                    <div class="dashboard-card">
                        <h3>点击率</h3>
                        <div class="number"><?php echo number_format($overall_stats['click_rate'], 2); ?></div>
                        <div class="desc">%</div>
                    </div>

                    <div class="dashboard-card">
                        <h3>转化率</h3>
                        <div class="number"><?php echo number_format($overall_stats['conversion_rate'], 2); ?></div>
                        <div class="desc">%</div>
                    </div>
                </div>
            </div>

            <!-- 活动效果排行（按ROI降序） -->
            <div class="table-container">
                <h3>活动效果排行TOP10</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>排名</th>
                            <th>活动名称</th>
                            <th>活动类型</th>
                            <th>触达人数</th>
                            <th>点击次数</th>
                            <th>转化次数</th>
                            <th>花费</th>
                            <th>收入</th>
                            <th>ROI</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($top_campaigns)): ?>
                            <tr>
                                <td colspan="9" class="text-center">暂无数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($top_campaigns as $index => $campaign): ?>
                                <tr>
                                    <td><?php echo $index + 1; ?></td>
                                    <td><?php echo htmlspecialchars($campaign['name']); ?></td>
                                    <td>
                                        <?php
                                        if ($campaign['type'] == 1) echo '线上活动';
                                        elseif ($campaign['type'] == 2) echo '线下活动';
                                        elseif ($campaign['type'] == 3) echo '联合营销';
                                        else echo '其他';
                                        ?>
                                    </td>
                                    <td><?php echo number_format($campaign['reach']); ?></td>
                                    <td><?php echo number_format($campaign['click']); ?></td>
                                    <td><?php echo number_format($campaign['conversion']); ?></td>
                                    <td><?php echo number_format($campaign['cost'], 2); ?></td>
                                    <td><?php echo number_format($campaign['revenue'], 2); ?></td>
                                    <td><?php echo number_format($campaign['roi'], 2); ?>%</td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 最高转化渠道TOP5 -->
            <div class="table-container">
                <h3>最高转化渠道TOP5</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>排名</th>
                            <th>渠道名称</th>
                            <th>渠道类型</th>
                            <th>所属活动</th>
                            <th>触达人数</th>
                            <th>点击次数</th>
                            <th>转化次数</th>
                            <th>转化率</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($top_conversion_channels)): ?>
                            <tr>
                                <td colspan="8" class="text-center">暂无数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($top_conversion_channels as $index => $channel): ?>
                                <tr>
                                    <td><?php echo $index + 1; ?></td>
                                    <td><?php echo htmlspecialchars($channel['name']); ?></td>
                                    <td><?php echo htmlspecialchars($channel['channel_type']); ?></td>
                                    <td><?php echo htmlspecialchars($channel['campaign_name']); ?></td>
                                    <td><?php echo number_format($channel['reach']); ?></td>
                                    <td><?php echo number_format($channel['click']); ?></td>
                                    <td><?php echo number_format($channel['conversion']); ?></td>
                                    <td><?php echo number_format($channel['conversion_rate'], 2); ?>%</td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 渠道类型效果分析 -->
            <div class="table-container">
                <h3>渠道类型效果分析</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>渠道类型</th>
                            <th>花费</th>
                            <th>占比</th>
                            <th>触达人数</th>
                            <th>点击次数</th>
                            <th>转化次数</th>
                            <th>ROI</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($channel_stats)): ?>
                            <tr>
                                <td colspan="7" class="text-center">暂无数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($channel_stats as $stat): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($stat['channel_name']); ?></td>
                                    <td><?php echo number_format($stat['cost'], 2); ?></td>
                                    <td>
                                        <?php echo $total_cost > 0 ? number_format(($stat['cost'] / $total_cost) * 100, 2) : '0.00'; ?>%
                                        <div class="progress-bar">
                                            <div class="progress" style="width: <?php echo $total_cost > 0 ? ($stat['cost'] / $total_cost) * 100 : 0; ?>%;"></div>
                                        </div>
                                    </td>
                                    <td><?php echo number_format($stat['reach']); ?></td>
                                    <td><?php echo number_format($stat['click']); ?></td>
                                    <td><?php echo number_format($stat['conversion']); ?></td>
                                    <td><?php echo number_format($stat['roi'], 2); ?>%</td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 营销效果趋势 - 表格形式 -->
            <div class="table-container">
                <h3>最近6个月营销效果趋势</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>指标</th>
                            <?php foreach ($months as $month): ?>
                                <th><?php echo $month; ?></th>
                            <?php endforeach; ?>
                        </tr>
                    </thead>
                    <tbody>
                        <tr>
                            <td>触达人数</td>
                            <?php foreach ($months as $month): ?>
                                <td><?php echo number_format($month_stats[$month]['reach']); ?></td>
                            <?php endforeach; ?>
                        </tr>
                        <tr>
                            <td>点击次数</td>
                            <?php foreach ($months as $month): ?>
                                <td><?php echo number_format($month_stats[$month]['click']); ?></td>
                            <?php endforeach; ?>
                        </tr>
                        <tr>
                            <td>转化次数</td>
                            <?php foreach ($months as $month): ?>
                                <td><?php echo number_format($month_stats[$month]['conversion']); ?></td>
                            <?php endforeach; ?>
                        </tr>
                        <tr>
                            <td>ROI</td>
                            <?php foreach ($months as $month): ?>
                                <td><?php echo number_format($month_stats[$month]['roi'], 2); ?>%</td>
                            <?php endforeach; ?>
                        </tr>
                    </tbody>
                </table>
            </div>

            <!-- 营销指标说明 -->
            <div class="info-box">
                <h3>营销指标说明</h3>
                <ul>
                    <li><strong>触达人数</strong>：营销内容被展示给用户的总人数。</li>
                    <li><strong>点击次数</strong>：用户点击营销内容的总次数。</li>
                    <li><strong>转化次数</strong>：用户完成目标行为（如注册、购买）的总次数。</li>
                    <li><strong>点击率</strong>：点击次数/触达人数，衡量营销内容的吸引力。</li>
                    <li><strong>转化率</strong>：转化次数/点击次数，衡量营销内容的有效性。</li>
                    <li><strong>ROI（投资回报率）</strong>：(收入-花费)/花费*100%，衡量营销活动的投资回报效果。</li>
                </ul>
            </div>
        </div>
    </div>
</body>

</html>