<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('product_catalog');

// 记录访问日志
record_log('访问产品目录页面');

// 添加/编辑产品处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加产品
    if ($_POST['action'] == 'add') {
        $product_code = isset($_POST['product_code']) ? trim($_POST['product_code']) : '';
        $name = isset($_POST['name']) ? trim($_POST['name']) : '';
        $category = isset($_POST['category']) ? intval($_POST['category']) : 1;
        $price = isset($_POST['price']) ? floatval($_POST['price']) : 0;
        $unit = isset($_POST['unit']) ? trim($_POST['unit']) : '';
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if (empty($product_code) || empty($name) || $price <= 0) {
            $error = '请填写完整产品信息！';
        } else {
            try {
                // 检查产品编码是否已存在
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM product_items WHERE product_code = ?");
                $stmt->execute([$product_code]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '产品编码已存在！';
                } else {
                    // 添加产品
                    $stmt = $pdo->prepare("INSERT INTO product_items (product_code, name, category, price, unit, status) VALUES (?, ?, ?, ?, ?, ?)");
                    $result = $stmt->execute([$product_code, $name, $category, $price, $unit, $status]);

                    if ($result) {
                        record_log("添加产品：{$name}");
                        $success = '产品添加成功！';
                        // 重定向到没有参数的页面
                        header('Location: catalog.php?success=add');
                        exit;
                    } else {
                        $error = '产品添加失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑产品
    elseif ($_POST['action'] == 'edit') {
        $product_id = isset($_POST['product_id']) ? intval($_POST['product_id']) : 0;
        $product_code = isset($_POST['product_code']) ? trim($_POST['product_code']) : '';
        $name = isset($_POST['name']) ? trim($_POST['name']) : '';
        $category = isset($_POST['category']) ? intval($_POST['category']) : 1;
        $price = isset($_POST['price']) ? floatval($_POST['price']) : 0;
        $unit = isset($_POST['unit']) ? trim($_POST['unit']) : '';
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($product_id <= 0 || empty($product_code) || empty($name) || $price <= 0) {
            $error = '请填写完整产品信息！';
        } else {
            try {
                // 检查产品编码是否已被其他产品使用
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM product_items WHERE product_code = ? AND id != ?");
                $stmt->execute([$product_code, $product_id]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '产品编码已被其他产品使用！';
                } else {
                    // 更新产品信息
                    $stmt = $pdo->prepare("UPDATE product_items SET product_code = ?, name = ?, category = ?, price = ?, unit = ?, status = ? WHERE id = ?");
                    $result = $stmt->execute([$product_code, $name, $category, $price, $unit, $status, $product_id]);

                    if ($result) {
                        record_log("编辑产品：{$name}");
                        $success = '产品信息更新成功！';
                        // 重定向到没有参数的页面
                        header('Location: catalog.php?success=edit');
                        exit;
                    } else {
                        $error = '产品信息更新失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除产品
    elseif ($_POST['action'] == 'delete') {
        $product_id = isset($_POST['product_id']) ? intval($_POST['product_id']) : 0;

        if ($product_id <= 0) {
            $error = '无效的产品ID！';
        } else {
            try {
                // 获取产品名称，用于日志记录
                $stmt = $pdo->prepare("SELECT name FROM product_items WHERE id = ?");
                $stmt->execute([$product_id]);
                $product = $stmt->fetch();

                if (!$product) {
                    $error = '产品不存在！';
                } else {
                    // 检查产品是否有关联库存
                    $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM product_inventory WHERE product_id = ?");
                    $stmt->execute([$product_id]);
                    $inventory = $stmt->fetch();

                    if ($inventory['count'] > 0) {
                        $error = '该产品存在库存记录，无法删除！';
                    } else {
                        // 删除产品
                        $stmt = $pdo->prepare("DELETE FROM product_items WHERE id = ?");
                        $result = $stmt->execute([$product_id]);

                        if ($result) {
                            record_log("删除产品：{$product['name']}");
                            $success = '产品删除成功！';
                        } else {
                            $error = '产品删除失败！';
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取所有产品
try {
    $stmt = $pdo->query("SELECT * FROM product_items ORDER BY id DESC");
    $products = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取产品列表失败：' . $e->getMessage();
    $products = [];
}

// 判断是否显示表单
$show_form = false;
$edit_product = null;

// 编辑产品时显示表单并获取产品信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM product_items WHERE id = ?");
        $stmt->execute([$edit_id]);
        $edit_product = $stmt->fetch();
        if (!$edit_product) {
            $error = '产品不存在！';
            $show_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取产品信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 添加产品时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '产品添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '产品信息更新成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>产品目录</h2>
            <div class="breadcrumb">
                <a href="index.php">产品管理</a> &gt; 产品目录
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="catalog.php?action=add" class="btn btn-add">添加产品</a>
            </div>

            <!-- 添加/编辑产品表单 -->
            <?php if ($show_form): ?>
                <div class="form-container">
                    <h3><?php echo $edit_product ? '编辑产品' : '添加产品'; ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_product ? 'edit' : 'add'; ?>">
                        <?php if ($edit_product): ?>
                            <input type="hidden" name="product_id" value="<?php echo $edit_product['id']; ?>">
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="product_code">产品编码：</label>
                            <input type="text" id="product_code" name="product_code" value="<?php echo $edit_product ? htmlspecialchars($edit_product['product_code']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="name">产品名称：</label>
                            <input type="text" id="name" name="name" value="<?php echo $edit_product ? htmlspecialchars($edit_product['name']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="category">产品分类：</label>
                            <select id="category" name="category">
                                <option value="1" <?php echo ($edit_product && $edit_product['category'] == 1) ? 'selected' : ''; ?>>软件</option>
                                <option value="2" <?php echo ($edit_product && $edit_product['category'] == 2) ? 'selected' : ''; ?>>服务</option>
                                <option value="3" <?php echo ($edit_product && $edit_product['category'] == 3) ? 'selected' : ''; ?>>硬件</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="price">标准价格：</label>
                            <input type="number" id="price" name="price" min="0" step="0.01" value="<?php echo $edit_product ? htmlspecialchars($edit_product['price']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="unit">单位：</label>
                            <input type="text" id="unit" name="unit" value="<?php echo $edit_product ? htmlspecialchars($edit_product['unit']) : ''; ?>">
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1" <?php echo ($edit_product && $edit_product['status'] == 1) ? 'selected' : ''; ?>>在售</option>
                                <option value="2" <?php echo ($edit_product && $edit_product['status'] == 2) ? 'selected' : ''; ?>>停售</option>
                                <option value="3" <?php echo ($edit_product && $edit_product['status'] == 3) ? 'selected' : ''; ?>>即将上市</option>
                            </select>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="catalog.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 产品列表 -->
            <div class="table-container">
                <h3>产品列表</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>产品编码</th>
                            <th>产品名称</th>
                            <th>分类</th>
                            <th>价格</th>
                            <th>单位</th>
                            <th>状态</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($products)): ?>
                            <tr>
                                <td colspan="9" class="text-center">暂无产品数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($products as $product): ?>
                                <tr>
                                    <td><?php echo $product['id']; ?></td>
                                    <td><?php echo htmlspecialchars($product['product_code']); ?></td>
                                    <td><?php echo htmlspecialchars($product['name']); ?></td>
                                    <td>
                                        <?php
                                        if ($product['category'] == 1) echo '软件';
                                        elseif ($product['category'] == 2) echo '服务';
                                        else echo '硬件';
                                        ?>
                                    </td>
                                    <td><?php echo number_format($product['price'], 2); ?></td>
                                    <td><?php echo htmlspecialchars($product['unit'] ?: '-'); ?></td>
                                    <td>
                                        <?php
                                        if ($product['status'] == 1) echo '<span class="status-active">在售</span>';
                                        elseif ($product['status'] == 2) echo '<span class="status-inactive">停售</span>';
                                        else echo '<span class="status-pending">即将上市</span>';
                                        ?>
                                    </td>
                                    <td><?php echo $product['create_time']; ?></td>
                                    <td>
                                        <a href="catalog.php?action=edit&id=<?php echo $product['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                        <form method="post" action="" class="inline-form">
                                            <input type="hidden" name="action" value="delete">
                                            <input type="hidden" name="product_id" value="<?php echo $product['id']; ?>">
                                            <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除产品 \'<?php echo htmlspecialchars($product['name']); ?>\' 吗？');">删除</button>
                                        </form>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>