<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('report_finance');

// 记录访问日志
record_log('访问财务数据分析页面');

// 获取分析数据的时间范围
$start_date = isset($_GET['start_date']) ? $_GET['start_date'] : date('Y-m-d', strtotime('-6 months'));
$end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d');

// 生成/导出报表处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 生成报表
    if ($_POST['action'] == 'generate') {
        $title = isset($_POST['title']) ? trim($_POST['title']) : '';
        $start_date = isset($_POST['start_date']) ? trim($_POST['start_date']) : '';
        $end_date = isset($_POST['end_date']) ? trim($_POST['end_date']) : '';
        $report_type = isset($_POST['report_type']) ? intval($_POST['report_type']) : 1;

        if (empty($title) || empty($start_date) || empty($end_date)) {
            $error = '请填写完整的报表信息！';
        } else {
            try {
                // 获取财务分析模板
                $stmt = $pdo->prepare("SELECT id FROM report_templates WHERE category = 5 AND name LIKE '%财务%' LIMIT 1");
                $stmt->execute();
                $template = $stmt->fetch();

                if (!$template) {
                    $error = '找不到财务分析模板！';
                } else {
                    // 构建查询参数
                    $params = json_encode([
                        'start_date' => $start_date,
                        'end_date' => $end_date,
                        'report_type' => $report_type
                    ]);

                    // 生成报表文件名（确保使用.csv扩展名）
                    $file_name = '财务数据分析_' . date('YmdHis') . '.csv';

                    // 确保reports目录存在
                    $reports_dir = __DIR__ . '/reports'; // 绝对路径
                    if (!is_dir($reports_dir)) {
                        if (!mkdir($reports_dir, 0755, true)) {
                            $error = '无法创建报表目录！';
                            throw new Exception('无法创建报表目录！');
                        }
                    }

                    // 完整的物理路径
                    $file_path = $reports_dir . '/' . $file_name;

                    // 数据库中存储的Web访问路径 - 修改为使用相对于网站根目录的路径
                    $web_file_path = 'report/reports/' . $file_name; // 关键修改：添加report/前缀

                    // 根据报表类型获取相应的数据
                    if ($report_type == 1 || $report_type == 3) {
                        // 获取月度收入数据
                        $stmt = $pdo->prepare("
                            SELECT 
                                DATE_FORMAT(payment_time, '%Y-%m') as month, 
                                SUM(amount) as total_amount
                            FROM finance_receipts 
                            WHERE payment_time BETWEEN ? AND ? AND status = 2
                            GROUP BY month 
                            ORDER BY month
                        ");
                        $stmt->execute([$start_date, $end_date]);
                        $monthly_income = $stmt->fetchAll();
                    }

                    if ($report_type == 1 || $report_type == 2) {
                        // 获取部门预算执行情况数据
                        $stmt = $pdo->prepare("
                            SELECT 
                                department,
                                CASE 
                                    WHEN type = 1 THEN '收入'
                                    WHEN type = 2 THEN '支出'
                                END as budget_type,
                                SUM(budget_amount) as budget_total,
                                SUM(actual_amount) as actual_total,
                                ROUND((SUM(actual_amount) / SUM(budget_amount)) * 100, 2) as execution_rate
                            FROM finance_budgets 
                            WHERE (year * 100 + month) BETWEEN 
                                  (YEAR(?) * 100 + MONTH(?)) AND (YEAR(?) * 100 + MONTH(?))
                            GROUP BY department, type
                            ORDER BY department, type
                        ");
                        $stmt->execute([$start_date, $start_date, $end_date, $end_date]);
                        $budget_data = $stmt->fetchAll();

                        // 获取应收账款情况
                        $stmt = $pdo->prepare("
                            SELECT 
                                CASE 
                                    WHEN status = 1 THEN '未收款'
                                    WHEN status = 2 THEN '部分收款'
                                    WHEN status = 3 THEN '已收款'
                                END as status_name,
                                COUNT(*) as count,
                                SUM(amount) as total_amount,
                                SUM(received_amount) as received_amount,
                                SUM(amount - received_amount) as remaining_amount
                            FROM finance_receivables 
                            WHERE create_time BETWEEN ? AND ? 
                            GROUP BY status
                            ORDER BY status
                        ");
                        $stmt->execute([$start_date, $end_date]);
                        $receivables_data = $stmt->fetchAll();

                        // 获取佣金统计数据
                        $stmt = $pdo->prepare("
                            SELECT 
                                CASE 
                                    WHEN status = 1 THEN '待发放'
                                    WHEN status = 2 THEN '已发放'
                                END as status_name,
                                COUNT(*) as count,
                                SUM(amount) as total_amount
                            FROM finance_commissions
                            WHERE create_time BETWEEN ? AND ? 
                            GROUP BY status
                            ORDER BY status
                        ");
                        $stmt->execute([$start_date, $end_date]);
                        $commission_data = $stmt->fetchAll();
                    }

                    // 创建并写入CSV文件
                    $file = fopen($file_path, 'w');

                    // 写入BOM头，确保Excel正确显示中文
                    fputs($file, "\xEF\xBB\xBF");

                    // 写入标题
                    fputcsv($file, [$title]);
                    fputcsv($file, ['报表生成时间：' . date('Y-m-d H:i:s')]);
                    fputcsv($file, ['统计时间范围：' . $start_date . ' 至 ' . $end_date]);
                    fputcsv($file, []);  // 空行

                    // 写入月度收入数据
                    if ($report_type == 1 || $report_type == 3) {
                        fputcsv($file, ['月度收入统计']);
                        fputcsv($file, ['月份', '收入金额']);
                        foreach ($monthly_income as $row) {
                            fputcsv($file, [$row['month'], number_format($row['total_amount'], 2)]);
                        }
                        fputcsv($file, []);  // 空行
                    }

                    // 写入部门预算执行情况
                    if ($report_type == 1 || $report_type == 2) {
                        fputcsv($file, ['部门预算执行情况']);
                        fputcsv($file, ['部门', '预算类型', '预算金额', '实际金额', '执行率']);
                        foreach ($budget_data as $row) {
                            fputcsv($file, [
                                $row['department'],
                                $row['budget_type'],
                                number_format($row['budget_total'], 2),
                                number_format($row['actual_total'], 2),
                                $row['execution_rate'] . '%'
                            ]);
                        }
                        fputcsv($file, []);  // 空行

                        // 写入应收账款情况
                        fputcsv($file, ['应收账款情况']);
                        fputcsv($file, ['状态', '数量', '应收总额', '已收金额', '未收金额', '收款率']);
                        foreach ($receivables_data as $row) {
                            $collection_rate = $row['total_amount'] > 0 ?
                                round(($row['received_amount'] / $row['total_amount']) * 100, 2) : 0;
                            fputcsv($file, [
                                $row['status_name'],
                                $row['count'],
                                number_format($row['total_amount'], 2),
                                number_format($row['received_amount'], 2),
                                number_format($row['remaining_amount'], 2),
                                $collection_rate . '%'
                            ]);
                        }
                        fputcsv($file, []);  // 空行

                        // 写入佣金统计
                        fputcsv($file, ['佣金统计']);
                        fputcsv($file, ['状态', '数量', '金额']);
                        foreach ($commission_data as $row) {
                            fputcsv($file, [
                                $row['status_name'],
                                $row['count'],
                                number_format($row['total_amount'], 2)
                            ]);
                        }
                    }

                    fclose($file);

                    // 添加报表记录
                    $stmt = $pdo->prepare("INSERT INTO report_records (template_id, title, params, file_path, creator_id) VALUES (?, ?, ?, ?, ?)");
                    $result = $stmt->execute([$template['id'], $title, $params, $web_file_path, $_SESSION['user_id']]);

                    if ($result) {
                        record_log("生成财务数据分析报表：{$title}");
                        $success = '报表生成成功！';
                    } else {
                        $error = '报表生成失败！';
                    }
                }
            } catch (Exception $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取月度收入数据
try {
    $stmt = $pdo->prepare("
        SELECT 
            DATE_FORMAT(payment_time, '%Y-%m') as month, 
            SUM(amount) as total_amount
        FROM finance_receipts 
        WHERE payment_time BETWEEN ? AND ? AND status = 2
        GROUP BY month 
        ORDER BY month
    ");
    $stmt->execute([$start_date, $end_date]);
    $monthly_income = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取月度收入数据失败：' . $e->getMessage();
    $monthly_income = [];
}

// 获取部门预算执行情况数据
try {
    $stmt = $pdo->prepare("
        SELECT 
            department,
            CASE 
                WHEN type = 1 THEN '收入'
                WHEN type = 2 THEN '支出'
            END as budget_type,
            SUM(budget_amount) as budget_total,
            SUM(actual_amount) as actual_total,
            ROUND((SUM(actual_amount) / SUM(budget_amount)) * 100, 2) as execution_rate
        FROM finance_budgets 
        WHERE (year * 100 + month) BETWEEN 
              (YEAR(?) * 100 + MONTH(?)) AND (YEAR(?) * 100 + MONTH(?))
        GROUP BY department, type
        ORDER BY department, type
    ");
    $stmt->execute([$start_date, $start_date, $end_date, $end_date]);
    $budget_execution = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取部门预算执行情况数据失败：' . $e->getMessage();
    $budget_execution = [];
}

// 获取应收账款情况
try {
    $stmt = $pdo->prepare("
        SELECT 
            CASE 
                WHEN status = 1 THEN '未收款'
                WHEN status = 2 THEN '部分收款'
                WHEN status = 3 THEN '已收款'
            END as status_name,
            COUNT(*) as count,
            SUM(amount) as total_amount,
            SUM(received_amount) as received_amount,
            SUM(amount - received_amount) as remaining_amount
        FROM finance_receivables 
        WHERE create_time BETWEEN ? AND ? 
        GROUP BY status
        ORDER BY status
    ");
    $stmt->execute([$start_date, $end_date]);
    $receivables_status = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取应收账款情况数据失败：' . $e->getMessage();
    $receivables_status = [];
}

// 获取佣金统计
try {
    $stmt = $pdo->prepare("
        SELECT 
            CASE 
                WHEN status = 1 THEN '待发放'
                WHEN status = 2 THEN '已发放'
            END as status_name,
            COUNT(*) as count,
            SUM(amount) as total_amount
        FROM finance_commissions
        WHERE create_time BETWEEN ? AND ? 
        GROUP BY status
        ORDER BY status
    ");
    $stmt->execute([$start_date, $end_date]);
    $commission_stats = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取佣金统计数据失败：' . $e->getMessage();
    $commission_stats = [];
}

// 获取最近的对账单数据
try {
    $stmt = $pdo->prepare("
        SELECT 
            s.id,
            s.statement_no,
            c.client_name,
            s.total_amount,
            s.received_amount,
            s.status,
            s.create_time
        FROM finance_statements s
        JOIN crm_clients c ON s.client_id = c.id
        WHERE s.create_time BETWEEN ? AND ? 
        ORDER BY s.create_time DESC
        LIMIT 10
    ");
    $stmt->execute([$start_date, $end_date]);
    $recent_statements = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取最近对账单数据失败：' . $e->getMessage();
    $recent_statements = [];
}

// 获取最近生成的财务分析报表
try {
    $stmt = $pdo->query("
        SELECT r.*, t.name as template_name, u.username 
        FROM report_records r
        JOIN report_templates t ON r.template_id = t.id 
        JOIN sys_users u ON r.creator_id = u.id 
        WHERE t.category = 5 AND t.name LIKE '%财务%'
        ORDER BY r.create_time DESC
        LIMIT 5
    ");
    $reports = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取报表记录失败：' . $e->getMessage();
    $reports = [];
}

// 计算统计数据
$total_income = 0;
foreach ($monthly_income as $month) {
    $total_income += $month['total_amount'];
}

// 计算应收账款总额和已收款总额
$total_receivable = 0;
$total_received = 0;
foreach ($receivables_status as $status) {
    $total_receivable += $status['total_amount'];
    $total_received += $status['received_amount'];
}
$collection_rate = $total_receivable > 0 ? round(($total_received / $total_receivable) * 100, 2) : 0;

// 计算部门预算差异
$total_budget = 0;
$total_actual = 0;
$departments_data = [];

foreach ($budget_execution as $budget) {
    if ($budget['budget_type'] == '收入') {
        $total_budget += $budget['budget_total'];
        $total_actual += $budget['actual_total'];
    }

    if (!isset($departments_data[$budget['department']])) {
        $departments_data[$budget['department']] = [
            'income_budget' => 0,
            'income_actual' => 0,
            'expense_budget' => 0,
            'expense_actual' => 0
        ];
    }

    if ($budget['budget_type'] == '收入') {
        $departments_data[$budget['department']]['income_budget'] = $budget['budget_total'];
        $departments_data[$budget['department']]['income_actual'] = $budget['actual_total'];
    } else {
        $departments_data[$budget['department']]['expense_budget'] = $budget['budget_total'];
        $departments_data[$budget['department']]['expense_actual'] = $budget['actual_total'];
    }
}

$budget_achievement_rate = $total_budget > 0 ? round(($total_actual / $total_budget) * 100, 2) : 0;
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>财务数据分析</h2>
            <div class="breadcrumb">
                <a href="index.php">数据分析与报表</a> &gt; 财务数据分析
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <!-- 筛选表单 -->
            <div class="filter-form">
                <h3>筛选条件</h3>
                <form method="get" action="">
                    <div class="form-group">
                        <label for="start_date">开始日期：</label>
                        <input type="date" id="start_date" name="start_date" value="<?php echo $start_date; ?>">
                    </div>

                    <div class="form-group">
                        <label for="end_date">结束日期：</label>
                        <input type="date" id="end_date" name="end_date" value="<?php echo $end_date; ?>">
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-primary">查询</button>
                    </div>
                </form>
            </div>

            <!-- 统计概览 -->
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>总收入</h3>
                    <div class="number"><?php echo number_format($total_income, 2); ?></div>
                    <div class="desc">所选时间范围内已确认收款总额</div>
                </div>

                <div class="dashboard-card">
                    <h3>收款率</h3>
                    <div class="number"><?php echo $collection_rate; ?>%</div>
                    <div class="desc">已收款金额/应收账款总额</div>
                </div>

                <div class="dashboard-card">
                    <h3>预算达成率</h3>
                    <div class="number"><?php echo $budget_achievement_rate; ?>%</div>
                    <div class="desc">实际收入/预算收入</div>
                </div>
            </div>

            <!-- 月度收入趋势 -->
            <div class="section">
                <h3>月度收入趋势</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>月份</th>
                            <th>收入金额</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($monthly_income)): ?>
                            <tr>
                                <td colspan="2" class="text-center">暂无数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($monthly_income as $month): ?>
                                <tr>
                                    <td><?php echo $month['month']; ?></td>
                                    <td><?php echo number_format($month['total_amount'], 2); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 部门预算执行情况 -->
            <div class="section">
                <h3>部门预算执行情况</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>部门</th>
                            <th>预算类型</th>
                            <th>预算金额</th>
                            <th>实际金额</th>
                            <th>执行率</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($budget_execution)): ?>
                            <tr>
                                <td colspan="5" class="text-center">暂无数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($budget_execution as $budget): ?>
                                <tr>
                                    <td><?php echo $budget['department']; ?></td>
                                    <td><?php echo $budget['budget_type']; ?></td>
                                    <td><?php echo number_format($budget['budget_total'], 2); ?></td>
                                    <td><?php echo number_format($budget['actual_total'], 2); ?></td>
                                    <td><?php echo $budget['execution_rate']; ?>%</td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 应收账款情况 -->
            <div class="section">
                <h3>应收账款情况</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>状态</th>
                            <th>数量</th>
                            <th>应收总额</th>
                            <th>已收金额</th>
                            <th>未收金额</th>
                            <th>收款率</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($receivables_status)): ?>
                            <tr>
                                <td colspan="6" class="text-center">暂无数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($receivables_status as $status):
                                $collection_rate = $status['total_amount'] > 0 ?
                                    round(($status['received_amount'] / $status['total_amount']) * 100, 2) : 0;
                            ?>
                                <tr>
                                    <td><?php echo $status['status_name']; ?></td>
                                    <td><?php echo $status['count']; ?></td>
                                    <td><?php echo number_format($status['total_amount'], 2); ?></td>
                                    <td><?php echo number_format($status['received_amount'], 2); ?></td>
                                    <td><?php echo number_format($status['remaining_amount'], 2); ?></td>
                                    <td><?php echo $collection_rate; ?>%</td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 佣金统计 -->
            <div class="section">
                <h3>佣金统计</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>状态</th>
                            <th>数量</th>
                            <th>金额</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($commission_stats)): ?>
                            <tr>
                                <td colspan="3" class="text-center">暂无数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($commission_stats as $commission): ?>
                                <tr>
                                    <td><?php echo $commission['status_name']; ?></td>
                                    <td><?php echo $commission['count']; ?></td>
                                    <td><?php echo number_format($commission['total_amount'], 2); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 最近对账单 -->
            <div class="section">
                <h3>最近对账单</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>对账单号</th>
                            <th>客户名称</th>
                            <th>总金额</th>
                            <th>已收金额</th>
                            <th>状态</th>
                            <th>创建时间</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($recent_statements)): ?>
                            <tr>
                                <td colspan="6" class="text-center">暂无数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($recent_statements as $statement): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($statement['statement_no']); ?></td>
                                    <td><?php echo htmlspecialchars($statement['client_name']); ?></td>
                                    <td><?php echo number_format($statement['total_amount'], 2); ?></td>
                                    <td><?php echo number_format($statement['received_amount'], 2); ?></td>
                                    <td>
                                        <?php
                                        if ($statement['status'] == 1) {
                                            echo '未确认';
                                        } else {
                                            echo '已确认';
                                        }
                                        ?>
                                    </td>
                                    <td><?php echo date('Y-m-d', strtotime($statement['create_time'])); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 生成报表 -->
            <div class="form-container">
                <h3>生成报表</h3>
                <form method="post" action="">
                    <input type="hidden" name="action" value="generate">

                    <div class="form-group">
                        <label for="title">报表标题：</label>
                        <input type="text" id="title" name="title" value="财务数据分析报表 <?php echo date('Y-m-d'); ?>" required>
                    </div>

                    <div class="form-group">
                        <label for="report_start_date">统计开始日期：</label>
                        <input type="date" id="report_start_date" name="start_date" value="<?php echo $start_date; ?>" required>
                    </div>

                    <div class="form-group">
                        <label for="report_end_date">统计结束日期：</label>
                        <input type="date" id="report_end_date" name="end_date" value="<?php echo $end_date; ?>" required>
                    </div>

                    <div class="form-group">
                        <label for="report_type">报表类型：</label>
                        <select id="report_type" name="report_type">
                            <option value="1">完整报表（包含所有数据）</option>
                            <option value="2">财务状况报表（侧重预算执行和应收账款）</option>
                            <option value="3">趋势报表（侧重月度收入趋势）</option>
                        </select>
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-success">生成报表</button>
                    </div>
                </form>
            </div>

            <!-- 历史报表 -->
            <div class="table-container">
                <h3>历史报表记录</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>报表标题</th>
                            <th>创建人</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($reports)): ?>
                            <tr>
                                <td colspan="4" class="text-center">暂无报表记录</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($reports as $report): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($report['title']); ?></td>
                                    <td><?php echo htmlspecialchars($report['username']); ?></td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($report['create_time'])); ?></td>
                                    <td>
                                        <a href="generate_report.php?id=<?php echo $report['id']; ?>" class="btn btn-sm btn-primary">下载</a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 分析说明 -->
            <div class="info-box">
                <h3>关于财务数据分析</h3>
                <p>财务数据分析帮助您了解：</p>
                <ul>
                    <li><strong>收入趋势</strong>：监控每月收入的变化，发现增长或下降的趋势。</li>
                    <li><strong>预算执行</strong>：分析各部门预算执行情况，评估财务管理效率。</li>
                    <li><strong>应收账款</strong>：跟踪应收账款收款情况，提高资金回收效率。</li>
                    <li><strong>佣金管理</strong>：了解佣金发放情况，合理控制销售成本。</li>
                </ul>
                <p>定期分析财务数据，可以帮助您优化资金流动，提高经营效益，为决策提供数据支持。</p>
            </div>
        </div>
    </div>
</body>

</html>