<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('sales_contract');

// 记录访问日志
record_log('访问合同管理页面');

// 添加/编辑/审批合同处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加合同
    if ($_POST['action'] == 'add') {
        $client_id = isset($_POST['client_id']) ? intval($_POST['client_id']) : 0;
        $lead_id = isset($_POST['lead_id']) ? intval($_POST['lead_id']) : null;
        $contract_no = isset($_POST['contract_no']) ? trim($_POST['contract_no']) : '';
        $amount = isset($_POST['amount']) ? floatval($_POST['amount']) : 0;
        $start_date = isset($_POST['start_date']) ? trim($_POST['start_date']) : '';
        $end_date = isset($_POST['end_date']) ? trim($_POST['end_date']) : '';
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($client_id <= 0 || empty($contract_no) || $amount <= 0 || empty($start_date) || empty($end_date)) {
            $error = '请填写完整合同信息！';
        } else {
            try {
                // 检查合同编号是否已存在
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM sales_contracts WHERE contract_no = ?");
                $stmt->execute([$contract_no]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '合同编号已存在！';
                } else {
                    // 添加合同
                    $stmt = $pdo->prepare("INSERT INTO sales_contracts (client_id, lead_id, contract_no, amount, start_date, end_date, status) VALUES (?, ?, ?, ?, ?, ?, ?)");
                    $result = $stmt->execute([$client_id, $lead_id ?: null, $contract_no, $amount, $start_date, $end_date, $status]);

                    if ($result) {
                        record_log("添加合同：{$contract_no}");
                        $success = '合同添加成功！';
                        // 重定向到没有参数的页面
                        header('Location: contract.php?success=add');
                        exit;
                    } else {
                        $error = '合同添加失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑合同
    elseif ($_POST['action'] == 'edit') {
        $contract_id = isset($_POST['contract_id']) ? intval($_POST['contract_id']) : 0;
        $client_id = isset($_POST['client_id']) ? intval($_POST['client_id']) : 0;
        $lead_id = isset($_POST['lead_id']) ? intval($_POST['lead_id']) : null;
        $contract_no = isset($_POST['contract_no']) ? trim($_POST['contract_no']) : '';
        $amount = isset($_POST['amount']) ? floatval($_POST['amount']) : 0;
        $start_date = isset($_POST['start_date']) ? trim($_POST['start_date']) : '';
        $end_date = isset($_POST['end_date']) ? trim($_POST['end_date']) : '';
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($contract_id <= 0 || $client_id <= 0 || empty($contract_no) || $amount <= 0 || empty($start_date) || empty($end_date)) {
            $error = '请填写完整合同信息！';
        } else {
            try {
                // 检查合同编号是否已被其他合同使用
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM sales_contracts WHERE contract_no = ? AND id != ?");
                $stmt->execute([$contract_no, $contract_id]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '合同编号已被其他合同使用！';
                } else {
                    // 更新合同信息
                    $stmt = $pdo->prepare("UPDATE sales_contracts SET client_id = ?, lead_id = ?, contract_no = ?, amount = ?, start_date = ?, end_date = ?, status = ? WHERE id = ?");
                    $result = $stmt->execute([$client_id, $lead_id ?: null, $contract_no, $amount, $start_date, $end_date, $status, $contract_id]);

                    if ($result) {
                        record_log("编辑合同：{$contract_no}");
                        $success = '合同信息更新成功！';
                        // 重定向到没有参数的页面
                        header('Location: contract.php?success=edit');
                        exit;
                    } else {
                        $error = '合同信息更新失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 更新合同状态
    elseif ($_POST['action'] == 'update_status') {
        $contract_id = isset($_POST['contract_id']) ? intval($_POST['contract_id']) : 0;
        $new_status = isset($_POST['new_status']) ? intval($_POST['new_status']) : 1;

        if ($contract_id <= 0) {
            $error = '无效的合同ID！';
        } else {
            try {
                // 获取当前合同信息
                $stmt = $pdo->prepare("SELECT contract_no, status FROM sales_contracts WHERE id = ?");
                $stmt->execute([$contract_id]);
                $contract = $stmt->fetch();

                if (!$contract) {
                    $error = '合同不存在！';
                } else {
                    // 检查状态是否有效
                    if ($new_status < 1 || $new_status > 3) {
                        $error = '无效的合同状态！';
                    } else {
                        // 更新合同状态
                        $stmt = $pdo->prepare("UPDATE sales_contracts SET status = ? WHERE id = ?");
                        $result = $stmt->execute([$new_status, $contract_id]);

                        if ($result) {
                            $status_text = '';
                            if ($new_status == 1) $status_text = '草稿';
                            elseif ($new_status == 2) $status_text = '审核中';
                            elseif ($new_status == 3) $status_text = '已生效';

                            record_log("更新合同状态：{$contract['contract_no']}，新状态：{$status_text}");
                            $success = '合同状态更新成功！';
                        } else {
                            $error = '合同状态更新失败！';
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除合同
    elseif ($_POST['action'] == 'delete') {
        $contract_id = isset($_POST['contract_id']) ? intval($_POST['contract_id']) : 0;

        if ($contract_id <= 0) {
            $error = '无效的合同ID！';
        } else {
            try {
                // 获取合同编号，用于日志记录
                $stmt = $pdo->prepare("SELECT contract_no FROM sales_contracts WHERE id = ?");
                $stmt->execute([$contract_id]);
                $contract = $stmt->fetch();

                if (!$contract) {
                    $error = '合同不存在！';
                } else {
                    // 检查是否有关联的订单等信息
                    // 这里可以根据实际情况添加检查逻辑

                    // 删除合同
                    $stmt = $pdo->prepare("DELETE FROM sales_contracts WHERE id = ?");
                    $result = $stmt->execute([$contract_id]);

                    if ($result) {
                        record_log("删除合同：{$contract['contract_no']}");
                        $success = '合同删除成功！';
                    } else {
                        $error = '合同删除失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取所有客户
try {
    $stmt = $pdo->query("SELECT id, client_name FROM crm_clients ORDER BY client_name");
    $clients = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取客户列表失败：' . $e->getMessage();
    $clients = [];
}

// 获取所有销售机会（用于关联）
try {
    $stmt = $pdo->query("SELECT id, name FROM sales_leads WHERE type = 2 ORDER BY id DESC");
    $leads = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取销售机会列表失败：' . $e->getMessage();
    $leads = [];
}

// 获取所有合同
try {
    $stmt = $pdo->query("
        SELECT c.*, 
               cl.client_name, 
               l.name as lead_name
        FROM sales_contracts c
        JOIN crm_clients cl ON c.client_id = cl.id
        LEFT JOIN sales_leads l ON c.lead_id = l.id
        ORDER BY c.create_time DESC
    ");
    $contracts = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取合同列表失败：' . $e->getMessage();
    $contracts = [];
}

// 判断是否显示表单
$show_form = false;
$edit_contract = null;

// 编辑合同时显示表单并获取合同信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM sales_contracts WHERE id = ?");
        $stmt->execute([$edit_id]);
        $edit_contract = $stmt->fetch();
        if (!$edit_contract) {
            $error = '合同不存在！';
            $show_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取合同信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 添加合同时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '合同添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '合同信息更新成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>合同管理</h2>
            <div class="breadcrumb">
                <a href="index.php">销售管理</a> &gt; 合同管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="contract.php?action=add" class="btn btn-add">添加合同</a>
            </div>

            <!-- 添加/编辑合同表单 -->
            <?php if ($show_form): ?>
                <div class="form-container">
                    <h3><?php echo $edit_contract ? '编辑合同' : '添加合同'; ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_contract ? 'edit' : 'add'; ?>">
                        <?php if ($edit_contract): ?>
                            <input type="hidden" name="contract_id" value="<?php echo $edit_contract['id']; ?>">
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="client_id">客户：</label>
                            <select id="client_id" name="client_id" required>
                                <option value="">请选择客户</option>
                                <?php foreach ($clients as $client): ?>
                                    <option value="<?php echo $client['id']; ?>" <?php echo ($edit_contract && $edit_contract['client_id'] == $client['id']) ? 'selected' : ''; ?>><?php echo htmlspecialchars($client['client_name']); ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="lead_id">关联销售机会：</label>
                            <select id="lead_id" name="lead_id">
                                <option value="">无关联销售机会</option>
                                <?php foreach ($leads as $lead): ?>
                                    <option value="<?php echo $lead['id']; ?>" <?php echo ($edit_contract && $edit_contract['lead_id'] == $lead['id']) ? 'selected' : ''; ?>><?php echo htmlspecialchars($lead['name']); ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="contract_no">合同编号：</label>
                            <input type="text" id="contract_no" name="contract_no" value="<?php echo $edit_contract ? htmlspecialchars($edit_contract['contract_no']) : ''; ?>" required>
                            <?php if (!$edit_contract): ?>
                                <small>推荐格式：HT-年月-序号，例如：HT-202305-001</small>
                            <?php endif; ?>
                        </div>

                        <div class="form-group">
                            <label for="amount">合同金额：</label>
                            <input type="number" id="amount" name="amount" step="0.01" min="0" value="<?php echo $edit_contract ? htmlspecialchars($edit_contract['amount']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="start_date">开始日期：</label>
                            <input type="date" id="start_date" name="start_date" value="<?php echo $edit_contract ? $edit_contract['start_date'] : date('Y-m-d'); ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="end_date">结束日期：</label>
                            <input type="date" id="end_date" name="end_date" value="<?php echo $edit_contract ? $edit_contract['end_date'] : date('Y-m-d', strtotime('+1 year')); ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1" <?php echo ($edit_contract && $edit_contract['status'] == 1) ? 'selected' : ''; ?>>草稿</option>
                                <option value="2" <?php echo ($edit_contract && $edit_contract['status'] == 2) ? 'selected' : ''; ?>>审核中</option>
                                <option value="3" <?php echo ($edit_contract && $edit_contract['status'] == 3) ? 'selected' : ''; ?>>已生效</option>
                            </select>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="contract.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 合同列表 -->
            <div class="table-container">
                <h3>合同列表</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>合同编号</th>
                            <th>客户名称</th>
                            <th>关联销售机会</th>
                            <th>金额</th>
                            <th>开始日期</th>
                            <th>结束日期</th>
                            <th>状态</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($contracts)): ?>
                            <tr>
                                <td colspan="10" class="text-center">暂无合同数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($contracts as $contract): ?>
                                <tr>
                                    <td><?php echo $contract['id']; ?></td>
                                    <td><?php echo htmlspecialchars($contract['contract_no']); ?></td>
                                    <td><?php echo htmlspecialchars($contract['client_name']); ?></td>
                                    <td><?php echo $contract['lead_id'] ? htmlspecialchars($contract['lead_name']) : '-'; ?></td>
                                    <td><?php echo number_format($contract['amount'], 2); ?></td>
                                    <td><?php echo $contract['start_date']; ?></td>
                                    <td><?php echo $contract['end_date']; ?></td>
                                    <td>
                                        <?php
                                        if ($contract['status'] == 1) echo '<span class="status-pending">草稿</span>';
                                        elseif ($contract['status'] == 2) echo '<span class="status-pending">审核中</span>';
                                        elseif ($contract['status'] == 3) echo '<span class="status-active">已生效</span>';
                                        ?>
                                    </td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($contract['create_time'])); ?></td>
                                    <td>
                                        <a href="contract.php?action=edit&id=<?php echo $contract['id']; ?>" class="btn btn-sm btn-edit">编辑</a>

                                        <?php if ($contract['status'] == 1): ?>
                                            <form method="post" action="" class="inline-form">
                                                <input type="hidden" name="action" value="update_status">
                                                <input type="hidden" name="contract_id" value="<?php echo $contract['id']; ?>">
                                                <input type="hidden" name="new_status" value="2">
                                                <button type="submit" class="btn btn-sm btn-primary" onclick="return confirm('确定要提交此合同进行审核吗？');">提交审核</button>
                                            </form>
                                        <?php elseif ($contract['status'] == 2): ?>
                                            <form method="post" action="" class="inline-form">
                                                <input type="hidden" name="action" value="update_status">
                                                <input type="hidden" name="contract_id" value="<?php echo $contract['id']; ?>">
                                                <input type="hidden" name="new_status" value="3">
                                                <button type="submit" class="btn btn-sm btn-success" onclick="return confirm('确定要审核通过此合同吗？');">审核通过</button>
                                            </form>
                                            <form method="post" action="" class="inline-form">
                                                <input type="hidden" name="action" value="update_status">
                                                <input type="hidden" name="contract_id" value="<?php echo $contract['id']; ?>">
                                                <input type="hidden" name="new_status" value="1">
                                                <button type="submit" class="btn btn-sm btn-secondary" onclick="return confirm('确定要退回此合同为草稿状态吗？');">退回修改</button>
                                            </form>
                                        <?php endif; ?>

                                        <?php if ($contract['status'] == 1): ?>
                                            <form method="post" action="" class="inline-form">
                                                <input type="hidden" name="action" value="delete">
                                                <input type="hidden" name="contract_id" value="<?php echo $contract['id']; ?>">
                                                <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除合同 \'<?php echo htmlspecialchars($contract['contract_no']); ?>\' 吗？');">删除</button>
                                            </form>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>