<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('sales_quote');

// 记录访问日志
record_log('访问报价单管理页面');

// 添加/编辑/更新报价单处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加报价单
    if ($_POST['action'] == 'add') {
        $client_id = isset($_POST['client_id']) ? intval($_POST['client_id']) : 0;
        $lead_id = isset($_POST['lead_id']) ? intval($_POST['lead_id']) : null;
        $quote_no = isset($_POST['quote_no']) ? trim($_POST['quote_no']) : '';
        $amount = isset($_POST['amount']) ? floatval($_POST['amount']) : 0;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($client_id <= 0 || empty($quote_no) || $amount <= 0) {
            $error = '请填写完整报价单信息！';
        } else {
            try {
                // 检查报价单号是否已存在
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM sales_quotes WHERE quote_no = ?");
                $stmt->execute([$quote_no]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '报价单号已存在！';
                } else {
                    // 添加报价单
                    $stmt = $pdo->prepare("INSERT INTO sales_quotes (client_id, lead_id, quote_no, amount, status) VALUES (?, ?, ?, ?, ?)");
                    $result = $stmt->execute([$client_id, $lead_id ?: null, $quote_no, $amount, $status]);

                    if ($result) {
                        record_log("添加报价单：{$quote_no}");
                        $success = '报价单添加成功！';
                        // 重定向到没有参数的页面
                        header('Location: quote.php?success=add');
                        exit;
                    } else {
                        $error = '报价单添加失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑报价单
    elseif ($_POST['action'] == 'edit') {
        $quote_id = isset($_POST['quote_id']) ? intval($_POST['quote_id']) : 0;
        $client_id = isset($_POST['client_id']) ? intval($_POST['client_id']) : 0;
        $lead_id = isset($_POST['lead_id']) ? intval($_POST['lead_id']) : null;
        $quote_no = isset($_POST['quote_no']) ? trim($_POST['quote_no']) : '';
        $amount = isset($_POST['amount']) ? floatval($_POST['amount']) : 0;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($quote_id <= 0 || $client_id <= 0 || empty($quote_no) || $amount <= 0) {
            $error = '请填写完整报价单信息！';
        } else {
            try {
                // 检查报价单号是否已被其他报价单使用
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM sales_quotes WHERE quote_no = ? AND id != ?");
                $stmt->execute([$quote_no, $quote_id]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '报价单号已被其他报价单使用！';
                } else {
                    // 更新报价单信息
                    $stmt = $pdo->prepare("UPDATE sales_quotes SET client_id = ?, lead_id = ?, quote_no = ?, amount = ?, status = ? WHERE id = ?");
                    $result = $stmt->execute([$client_id, $lead_id ?: null, $quote_no, $amount, $status, $quote_id]);

                    if ($result) {
                        record_log("编辑报价单：{$quote_no}");
                        $success = '报价单信息更新成功！';
                        // 重定向到没有参数的页面
                        header('Location: quote.php?success=edit');
                        exit;
                    } else {
                        $error = '报价单信息更新失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 更新报价单状态
    elseif ($_POST['action'] == 'update_status') {
        $quote_id = isset($_POST['quote_id']) ? intval($_POST['quote_id']) : 0;
        $new_status = isset($_POST['new_status']) ? intval($_POST['new_status']) : 1;

        if ($quote_id <= 0) {
            $error = '无效的报价单ID！';
        } else {
            try {
                // 获取当前报价单信息
                $stmt = $pdo->prepare("SELECT quote_no, status FROM sales_quotes WHERE id = ?");
                $stmt->execute([$quote_id]);
                $quote = $stmt->fetch();

                if (!$quote) {
                    $error = '报价单不存在！';
                } else {
                    // 检查状态是否有效
                    if ($new_status < 1 || $new_status > 3) {
                        $error = '无效的报价单状态！';
                    } else {
                        // 更新报价单状态
                        $stmt = $pdo->prepare("UPDATE sales_quotes SET status = ? WHERE id = ?");
                        $result = $stmt->execute([$new_status, $quote_id]);

                        if ($result) {
                            $status_text = '';
                            if ($new_status == 1) $status_text = '草稿';
                            elseif ($new_status == 2) $status_text = '已发送';
                            elseif ($new_status == 3) $status_text = '已接受';

                            record_log("更新报价单状态：{$quote['quote_no']}，新状态：{$status_text}");
                            $success = '报价单状态更新成功！';
                        } else {
                            $error = '报价单状态更新失败！';
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除报价单
    elseif ($_POST['action'] == 'delete') {
        $quote_id = isset($_POST['quote_id']) ? intval($_POST['quote_id']) : 0;

        if ($quote_id <= 0) {
            $error = '无效的报价单ID！';
        } else {
            try {
                // 获取报价单号和状态，用于日志记录和检查是否为草稿状态
                $stmt = $pdo->prepare("SELECT quote_no, status FROM sales_quotes WHERE id = ?");
                $stmt->execute([$quote_id]);
                $quote = $stmt->fetch();

                if (!$quote) {
                    $error = '报价单不存在！';
                } else {
                    // 检查是否为草稿状态
                    if ($quote['status'] != 1) {
                        $error = '只能删除草稿状态的报价单！';
                    } else {
                        // 删除报价单
                        $stmt = $pdo->prepare("DELETE FROM sales_quotes WHERE id = ?");
                        $result = $stmt->execute([$quote_id]);

                        if ($result) {
                            record_log("删除报价单：{$quote['quote_no']}");
                            $success = '报价单删除成功！';
                        } else {
                            $error = '报价单删除失败！';
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 创建合同
if (isset($_GET['action']) && $_GET['action'] == 'create_contract' && isset($_GET['id'])) {
    $quote_id = intval($_GET['id']);

    try {
        // 获取报价单信息
        $stmt = $pdo->prepare("
            SELECT q.*, c.client_name 
            FROM sales_quotes q 
            JOIN crm_clients c ON q.client_id = c.id 
            WHERE q.id = ?
        ");
        $stmt->execute([$quote_id]);
        $quote = $stmt->fetch();

        if (!$quote) {
            $error = '报价单不存在！';
        } else {
            // 生成合同编号
            $contract_no = 'HT-' . date('Ym') . '-' . str_pad(rand(1, 999), 3, '0', STR_PAD_LEFT);

            // 插入合同记录
            $stmt = $pdo->prepare("
                INSERT INTO sales_contracts 
                (client_id, lead_id, contract_no, amount, start_date, end_date, status) 
                VALUES (?, ?, ?, ?, ?, ?, 1)
            ");
            $result = $stmt->execute([
                $quote['client_id'],
                $quote['lead_id'],
                $contract_no,
                $quote['amount'],
                date('Y-m-d'),
                date('Y-m-d', strtotime('+1 year'))
            ]);

            if ($result) {
                // 更新报价单状态为已接受
                $stmt = $pdo->prepare("UPDATE sales_quotes SET status = 3 WHERE id = ?");
                $stmt->execute([$quote_id]);

                record_log("基于报价单{$quote['quote_no']}创建合同：{$contract_no}");
                $success = "已基于报价单成功创建合同！合同编号：{$contract_no}";

                // 重定向到合同页面
                header('Location: contract.php?success=add_from_quote');
                exit;
            } else {
                $error = '创建合同失败！';
            }
        }
    } catch (PDOException $e) {
        $error = '系统错误：' . $e->getMessage();
    }
}

// 获取所有客户
try {
    $stmt = $pdo->query("SELECT id, client_name FROM crm_clients ORDER BY client_name");
    $clients = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取客户列表失败：' . $e->getMessage();
    $clients = [];
}

// 获取所有销售机会（用于关联）
try {
    $stmt = $pdo->query("SELECT id, name FROM sales_leads WHERE type = 2 ORDER BY id DESC");
    $leads = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取销售机会列表失败：' . $e->getMessage();
    $leads = [];
}

// 获取所有报价单
try {
    $stmt = $pdo->query("
        SELECT q.*, 
               c.client_name, 
               l.name as lead_name
        FROM sales_quotes q
        JOIN crm_clients c ON q.client_id = c.id
        LEFT JOIN sales_leads l ON q.lead_id = l.id
        ORDER BY q.create_time DESC
    ");
    $quotes = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取报价单列表失败：' . $e->getMessage();
    $quotes = [];
}

// 判断是否显示表单
$show_form = false;
$edit_quote = null;

// 编辑报价单时显示表单并获取报价单信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM sales_quotes WHERE id = ?");
        $stmt->execute([$edit_id]);
        $edit_quote = $stmt->fetch();
        if (!$edit_quote) {
            $error = '报价单不存在！';
            $show_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取报价单信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 添加报价单时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '报价单添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '报价单信息更新成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>报价管理</h2>
            <div class="breadcrumb">
                <a href="index.php">销售管理</a> &gt; 报价管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="quote.php?action=add" class="btn btn-add">添加报价单</a>
            </div>

            <!-- 添加/编辑报价单表单 -->
            <?php if ($show_form): ?>
                <div class="form-container">
                    <h3><?php echo $edit_quote ? '编辑报价单' : '添加报价单'; ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_quote ? 'edit' : 'add'; ?>">
                        <?php if ($edit_quote): ?>
                            <input type="hidden" name="quote_id" value="<?php echo $edit_quote['id']; ?>">
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="client_id">客户：</label>
                            <select id="client_id" name="client_id" required>
                                <option value="">请选择客户</option>
                                <?php foreach ($clients as $client): ?>
                                    <option value="<?php echo $client['id']; ?>" <?php echo ($edit_quote && $edit_quote['client_id'] == $client['id']) ? 'selected' : ''; ?>><?php echo htmlspecialchars($client['client_name']); ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="lead_id">关联销售机会：</label>
                            <select id="lead_id" name="lead_id">
                                <option value="">无关联销售机会</option>
                                <?php foreach ($leads as $lead): ?>
                                    <option value="<?php echo $lead['id']; ?>" <?php echo ($edit_quote && $edit_quote['lead_id'] == $lead['id']) ? 'selected' : ''; ?>><?php echo htmlspecialchars($lead['name']); ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="quote_no">报价单号：</label>
                            <input type="text" id="quote_no" name="quote_no" value="<?php echo $edit_quote ? htmlspecialchars($edit_quote['quote_no']) : ''; ?>" required>
                            <?php if (!$edit_quote): ?>
                                <small>推荐格式：BJ-年月-序号，例如：BJ-202305-001</small>
                            <?php endif; ?>
                        </div>

                        <div class="form-group">
                            <label for="amount">报价金额：</label>
                            <input type="number" id="amount" name="amount" step="0.01" min="0" value="<?php echo $edit_quote ? htmlspecialchars($edit_quote['amount']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1" <?php echo ($edit_quote && $edit_quote['status'] == 1) ? 'selected' : ''; ?>>草稿</option>
                                <option value="2" <?php echo ($edit_quote && $edit_quote['status'] == 2) ? 'selected' : ''; ?>>已发送</option>
                                <option value="3" <?php echo ($edit_quote && $edit_quote['status'] == 3) ? 'selected' : ''; ?>>已接受</option>
                            </select>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="quote.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 报价单列表 -->
            <div class="table-container">
                <h3>报价单列表</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>报价单号</th>
                            <th>客户名称</th>
                            <th>关联销售机会</th>
                            <th>金额</th>
                            <th>状态</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($quotes)): ?>
                            <tr>
                                <td colspan="8" class="text-center">暂无报价单数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($quotes as $quote): ?>
                                <tr>
                                    <td><?php echo $quote['id']; ?></td>
                                    <td><?php echo htmlspecialchars($quote['quote_no']); ?></td>
                                    <td><?php echo htmlspecialchars($quote['client_name']); ?></td>
                                    <td><?php echo $quote['lead_id'] ? htmlspecialchars($quote['lead_name']) : '-'; ?></td>
                                    <td><?php echo number_format($quote['amount'], 2); ?></td>
                                    <td>
                                        <?php
                                        if ($quote['status'] == 1) echo '<span class="status-pending">草稿</span>';
                                        elseif ($quote['status'] == 2) echo '<span class="status-pending">已发送</span>';
                                        elseif ($quote['status'] == 3) echo '<span class="status-active">已接受</span>';
                                        ?>
                                    </td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($quote['create_time'])); ?></td>
                                    <td>
                                        <a href="quote.php?action=edit&id=<?php echo $quote['id']; ?>" class="btn btn-sm btn-edit">编辑</a>

                                        <?php if ($quote['status'] == 1): ?>
                                            <form method="post" action="" class="inline-form">
                                                <input type="hidden" name="action" value="update_status">
                                                <input type="hidden" name="quote_id" value="<?php echo $quote['id']; ?>">
                                                <input type="hidden" name="new_status" value="2">
                                                <button type="submit" class="btn btn-sm btn-primary" onclick="return confirm('确定要将报价单标记为已发送吗？');">标记已发送</button>
                                            </form>
                                        <?php elseif ($quote['status'] == 2): ?>
                                            <form method="post" action="" class="inline-form">
                                                <input type="hidden" name="action" value="update_status">
                                                <input type="hidden" name="quote_id" value="<?php echo $quote['id']; ?>">
                                                <input type="hidden" name="new_status" value="3">
                                                <button type="submit" class="btn btn-sm btn-success" onclick="return confirm('确定要将报价单标记为已接受吗？');">标记已接受</button>
                                            </form>
                                            <form method="post" action="" class="inline-form">
                                                <input type="hidden" name="action" value="update_status">
                                                <input type="hidden" name="quote_id" value="<?php echo $quote['id']; ?>">
                                                <input type="hidden" name="new_status" value="1">
                                                <button type="submit" class="btn btn-sm btn-secondary" onclick="return confirm('确定要将报价单退回为草稿状态吗？');">退回修改</button>
                                            </form>
                                        <?php endif; ?>

                                        <?php if ($quote['status'] == 2 || $quote['status'] == 3): ?>
                                            <a href="quote.php?action=create_contract&id=<?php echo $quote['id']; ?>" class="btn btn-sm btn-primary" onclick="return confirm('确定要基于此报价单创建合同吗？');">创建合同</a>
                                        <?php endif; ?>

                                        <?php if ($quote['status'] == 1): ?>
                                            <form method="post" action="" class="inline-form">
                                                <input type="hidden" name="action" value="delete">
                                                <input type="hidden" name="quote_id" value="<?php echo $quote['id']; ?>">
                                                <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除报价单 \'<?php echo htmlspecialchars($quote['quote_no']); ?>\' 吗？');">删除</button>
                                            </form>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>