<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('service_survey');

// 记录访问日志
record_log('访问满意度调查管理页面');

// 添加调查记录
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加满意度调查
    if ($_POST['action'] == 'add') {
        $client_id = isset($_POST['client_id']) ? intval($_POST['client_id']) : 0;
        $score = isset($_POST['score']) ? intval($_POST['score']) : 0;
        $comment = isset($_POST['comment']) ? trim($_POST['comment']) : '';

        if ($client_id <= 0 || $score <= 0 || $score > 5) {
            $error = '请选择客户并提供有效的评分（1-5分）！';
        } else {
            try {
                // 检查客户是否存在
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM crm_clients WHERE id = ?");
                $stmt->execute([$client_id]);
                $result = $stmt->fetch();

                if ($result['count'] == 0) {
                    $error = '所选客户不存在！';
                } else {
                    // 添加满意度调查记录
                    $stmt = $pdo->prepare("INSERT INTO service_satisfaction (client_id, score, comment) VALUES (?, ?, ?)");
                    $result = $stmt->execute([$client_id, $score, $comment]);

                    if ($result) {
                        record_log("添加满意度调查记录，客户ID：{$client_id}，评分：{$score}");
                        $success = '满意度调查记录添加成功！';
                        // 重定向到没有参数的页面
                        header('Location: survey.php?success=add');
                        exit;
                    } else {
                        $error = '满意度调查记录添加失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除调查记录
    elseif ($_POST['action'] == 'delete') {
        $survey_id = isset($_POST['survey_id']) ? intval($_POST['survey_id']) : 0;

        if ($survey_id <= 0) {
            $error = '无效的调查记录ID！';
        } else {
            try {
                // 删除调查记录
                $stmt = $pdo->prepare("DELETE FROM service_satisfaction WHERE id = ?");
                $result = $stmt->execute([$survey_id]);

                if ($result) {
                    record_log("删除满意度调查记录ID：{$survey_id}");
                    $success = '满意度调查记录删除成功！';
                } else {
                    $error = '满意度调查记录删除失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取筛选参数
$score_filter = isset($_GET['score']) ? intval($_GET['score']) : 0;
$date_filter = isset($_GET['date']) ? $_GET['date'] : '';

// 构建筛选条件
$where_conditions = [];
$params = [];

if ($score_filter > 0) {
    $where_conditions[] = "s.score = ?";
    $params[] = $score_filter;
}

if (!empty($date_filter)) {
    $where_conditions[] = "DATE(s.create_time) = ?";
    $params[] = $date_filter;
}

$where_clause = !empty($where_conditions) ? "WHERE " . implode(" AND ", $where_conditions) : "";

// 获取所有满意度调查记录
try {
    $sql = "SELECT s.*, c.client_name 
            FROM service_satisfaction s
            JOIN crm_clients c ON s.client_id = c.id
            {$where_clause}
            ORDER BY s.create_time DESC";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $surveys = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取满意度调查记录失败：' . $e->getMessage();
    $surveys = [];
}

// 获取所有客户，用于添加满意度调查
try {
    $stmt = $pdo->query("SELECT id, client_name FROM crm_clients ORDER BY client_name");
    $clients = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取客户列表失败：' . $e->getMessage();
    $clients = [];
}

// 计算平均满意度
$avg_score = 0;
$score_counts = [1 => 0, 2 => 0, 3 => 0, 4 => 0, 5 => 0];
$total_surveys = count($surveys);

if ($total_surveys > 0) {
    $total_score = 0;
    foreach ($surveys as $survey) {
        $total_score += $survey['score'];
        $score_counts[$survey['score']]++;
    }
    $avg_score = round($total_score / $total_surveys, 1);
}

// 判断是否显示表单
$show_form = false;

// 添加满意度调查时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '满意度调查记录添加成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>满意度调查管理</h2>
            <div class="breadcrumb">
                <a href="index.php">客户服务与售后</a> &gt; 满意度调查管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <!-- 满意度统计概览 -->
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>平均满意度</h3>
                    <div class="number"><?php echo $avg_score; ?></div>
                    <div class="desc">满分5分</div>
                </div>

                <div class="dashboard-card">
                    <h3>调查总数</h3>
                    <div class="number"><?php echo $total_surveys; ?></div>
                    <div class="desc">满意度调查记录</div>
                </div>

                <div class="dashboard-card">
                    <h3>5分评价</h3>
                    <div class="number"><?php echo $score_counts[5]; ?></div>
                    <div class="desc"><a href="?score=5">查看详情</a></div>
                </div>

                <div class="dashboard-card">
                    <h3>4分评价</h3>
                    <div class="number"><?php echo $score_counts[4]; ?></div>
                    <div class="desc"><a href="?score=4">查看详情</a></div>
                </div>

                <div class="dashboard-card">
                    <h3>3分及以下</h3>
                    <div class="number"><?php echo $score_counts[1] + $score_counts[2] + $score_counts[3]; ?></div>
                    <div class="desc">需关注</div>
                </div>
            </div>

            <div class="action-bar">
                <a href="survey.php?action=add" class="btn btn-add">添加满意度调查</a>
                <a href="survey.php" class="btn btn-secondary">全部记录</a>
            </div>

            <!-- 添加满意度调查表单 -->
            <?php if ($show_form): ?>
                <div class="form-container">
                    <h3>添加满意度调查</h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="add">

                        <div class="form-group">
                            <label for="client_id">选择客户：</label>
                            <select id="client_id" name="client_id" required>
                                <option value="">请选择</option>
                                <?php foreach ($clients as $client): ?>
                                    <option value="<?php echo $client['id']; ?>"><?php echo htmlspecialchars($client['client_name']); ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="score">满意度评分：</label>
                            <select id="score" name="score" required>
                                <option value="">请选择</option>
                                <option value="5">5分（非常满意）</option>
                                <option value="4">4分（满意）</option>
                                <option value="3">3分（一般）</option>
                                <option value="2">2分（不满意）</option>
                                <option value="1">1分（非常不满意）</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="comment">评价内容：</label>
                            <textarea id="comment" name="comment" rows="4"></textarea>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">提交调查</button>
                            <a href="survey.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php endif; ?>

            <!-- 满意度调查筛选表单 -->
            <div class="filter-form">
                <form method="get" action="">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="score">评分：</label>
                            <select id="score" name="score" onchange="this.form.submit()">
                                <option value="0">全部</option>
                                <option value="5" <?php echo $score_filter == 5 ? 'selected' : ''; ?>>5分（非常满意）</option>
                                <option value="4" <?php echo $score_filter == 4 ? 'selected' : ''; ?>>4分（满意）</option>
                                <option value="3" <?php echo $score_filter == 3 ? 'selected' : ''; ?>>3分（一般）</option>
                                <option value="2" <?php echo $score_filter == 2 ? 'selected' : ''; ?>>2分（不满意）</option>
                                <option value="1" <?php echo $score_filter == 1 ? 'selected' : ''; ?>>1分（非常不满意）</option>
                            </select>
                        </div>

                        <div class="filter-item">
                            <label for="date">日期：</label>
                            <input type="date" id="date" name="date" value="<?php echo $date_filter; ?>" onchange="this.form.submit()">
                        </div>
                    </div>
                </form>
            </div>

            <!-- 满意度调查列表 -->
            <div class="table-container">
                <h3>满意度调查列表</h3>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>客户</th>
                            <th>评分</th>
                            <th>评价内容</th>
                            <th>提交时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($surveys)): ?>
                            <tr>
                                <td colspan="6" class="text-center">暂无满意度调查记录</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($surveys as $survey): ?>
                                <tr>
                                    <td><?php echo $survey['id']; ?></td>
                                    <td><?php echo htmlspecialchars($survey['client_name']); ?></td>
                                    <td>
                                        <?php
                                        $star_rating = '';
                                        for ($i = 1; $i <= 5; $i++) {
                                            $star_rating .= $i <= $survey['score'] ? '★' : '☆';
                                        }
                                        echo $star_rating . ' (' . $survey['score'] . '分)';
                                        ?>
                                    </td>
                                    <td><?php echo isset($survey['comment']) ? htmlspecialchars($survey['comment']) : ''; ?></td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($survey['create_time'])); ?></td>
                                    <td>
                                        <form method="post" action="">
                                            <input type="hidden" name="action" value="delete">
                                            <input type="hidden" name="survey_id" value="<?php echo $survey['id']; ?>">
                                            <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除此满意度调查记录吗？');">删除</button>
                                        </form>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 使用说明 -->
            <div class="info-box">
                <h3>满意度调查管理说明</h3>
                <ul>
                    <li>本页面用于管理客户满意度调查记录，包括查看和添加满意度评价。</li>
                    <li>满意度评分采用1-5分制，5分表示非常满意，1分表示非常不满意。</li>
                    <li>您可以为客户手动添加满意度评价，也可以查看现有的满意度评价记录。</li>
                    <li>满意度统计概览显示平均满意度分数和各分值的评价数量，便于整体把握客户满意度情况。</li>
                    <li>3分及以下的评价需要特别关注，可能反映客户服务中存在的问题。</li>
                    <li>您可以使用筛选功能查看特定评分或日期的满意度调查记录。</li>
                </ul>
            </div>
        </div>
    </div>
</body>

</html>