<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('task');

// 记录访问日志
record_log('访问任务与日程管理页面');

// 获取待办事项总数
try {
    $stmt = $pdo->prepare("
        SELECT COUNT(*) as count 
        FROM task_todos 
        WHERE user_id = ? AND status = 1
    ");
    $stmt->execute([$_SESSION['user_id']]);
    $todo_count = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取待办事项数据失败：' . $e->getMessage();
    $todo_count = ['count' => 0];
}

// 获取今日日程安排数量
try {
    $today = date('Y-m-d');
    $stmt = $pdo->prepare("
        SELECT COUNT(*) as count 
        FROM task_schedules 
        WHERE user_id = ? 
        AND DATE(start_time) <= ? 
        AND DATE(end_time) >= ?
    ");
    $stmt->execute([$_SESSION['user_id'], $today, $today]);
    $schedule_count = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取日程安排数据失败：' . $e->getMessage();
    $schedule_count = ['count' => 0];
}

// 获取未读提醒数量
try {
    $stmt = $pdo->prepare("
        SELECT COUNT(*) as count 
        FROM task_reminders 
        WHERE user_id = ? AND status = 1
    ");
    $stmt->execute([$_SESSION['user_id']]);
    $reminder_count = $stmt->fetch();
} catch (PDOException $e) {
    $error = '获取提醒数据失败：' . $e->getMessage();
    $reminder_count = ['count' => 0];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>任务与日程管理</h2>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <h2>工作概览</h2>
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>待办事项</h3>
                    <div class="number"><?php echo $todo_count['count']; ?></div>
                    <div class="desc">待处理的任务</div>
                </div>

                <div class="dashboard-card">
                    <h3>今日日程</h3>
                    <div class="number"><?php echo $schedule_count['count']; ?></div>
                    <div class="desc">今天的日程安排</div>
                </div>

                <div class="dashboard-card">
                    <h3>未读提醒</h3>
                    <div class="number"><?php echo $reminder_count['count']; ?></div>
                    <div class="desc">未读的系统提醒</div>
                </div>
            </div>

            <h2>功能导航</h2>
            <div class="function-links">
                <a href="todo.php" class="function-link">
                    <h3>待办事项</h3>
                </a>
                <a href="schedule.php" class="function-link">
                    <h3>日程安排</h3>
                </a>
                <a href="notify.php" class="function-link">
                    <h3>提醒通知</h3>
                </a>
                <a href="team.php" class="function-link">
                    <h3>团队协作</h3>
                </a>
            </div>

            <h2>今日日程</h2>
            <div class="recent-operations">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>时间</th>
                            <th>事项</th>
                            <th>类型</th>
                            <th>地点</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        try {
                            $stmt = $pdo->prepare("
                                SELECT s.*, 
                                       TIME_FORMAT(s.start_time, '%H:%i') as start_time_format, 
                                       TIME_FORMAT(s.end_time, '%H:%i') as end_time_format,
                                       CASE 
                                           WHEN s.type = 1 THEN '拜访'
                                           WHEN s.type = 2 THEN '会议'
                                           ELSE '其他'
                                       END as type_text
                                FROM task_schedules s 
                                WHERE s.user_id = ?
                                AND DATE(s.start_time) <= ? 
                                AND DATE(s.end_time) >= ?
                                ORDER BY s.start_time ASC 
                                LIMIT 5
                            ");
                            $stmt->execute([$_SESSION['user_id'], $today, $today]);
                            $schedules = $stmt->fetchAll();

                            if (empty($schedules)): ?>
                                <tr>
                                    <td colspan="4" class="text-center">今日暂无日程安排</td>
                                </tr>
                                <?php else:
                                foreach ($schedules as $schedule): ?>
                                    <tr>
                                        <td><?php echo $schedule['start_time_format']; ?> - <?php echo $schedule['end_time_format']; ?></td>
                                        <td><?php echo htmlspecialchars($schedule['title']); ?></td>
                                        <td><?php echo $schedule['type_text']; ?></td>
                                        <td><?php echo htmlspecialchars($schedule['location'] ?? '无'); ?></td>
                                    </tr>
                            <?php endforeach;
                            endif;
                        } catch (PDOException $e) { ?>
                            <tr>
                                <td colspan="4" class="text-center">获取日程安排失败：<?php echo $e->getMessage(); ?></td>
                            </tr>
                        <?php } ?>
                    </tbody>
                </table>
            </div>

            <h2>待办事项</h2>
            <div class="recent-operations">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>标题</th>
                            <th>类型</th>
                            <th>优先级</th>
                            <th>截止时间</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        try {
                            $stmt = $pdo->prepare("
                                SELECT t.*, 
                                       CASE 
                                           WHEN t.priority = 3 THEN '高'
                                           WHEN t.priority = 2 THEN '中'
                                           ELSE '低'
                                       END as priority_text,
                                       CASE 
                                           WHEN t.type = 1 THEN '个人'
                                           ELSE '团队'
                                       END as type_text
                                FROM task_todos t 
                                WHERE t.user_id = ? AND t.status = 1
                                ORDER BY t.priority DESC, t.end_time ASC 
                                LIMIT 5
                            ");
                            $stmt->execute([$_SESSION['user_id']]);
                            $todos = $stmt->fetchAll();

                            if (empty($todos)): ?>
                                <tr>
                                    <td colspan="4" class="text-center">暂无待办事项</td>
                                </tr>
                                <?php else:
                                foreach ($todos as $todo): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($todo['title']); ?></td>
                                        <td><?php echo $todo['type_text']; ?></td>
                                        <td><?php echo $todo['priority_text']; ?></td>
                                        <td><?php echo $todo['end_time'] ? date('Y-m-d H:i', strtotime($todo['end_time'])) : '无'; ?></td>
                                    </tr>
                            <?php endforeach;
                            endif;
                        } catch (PDOException $e) { ?>
                            <tr>
                                <td colspan="4" class="text-center">获取待办事项失败：<?php echo $e->getMessage(); ?></td>
                            </tr>
                        <?php } ?>
                    </tbody>
                </table>
            </div>

            <h2>最近提醒</h2>
            <div class="recent-operations">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>标题</th>
                            <th>提醒类型</th>
                            <th>提醒时间</th>
                            <th>状态</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        try {
                            $stmt = $pdo->prepare("
                                SELECT r.*, 
                                       CASE 
                                           WHEN r.type = 1 THEN '系统'
                                           WHEN r.type = 2 THEN '邮件'
                                           ELSE '短信'
                                       END as type_text,
                                       CASE 
                                           WHEN r.status = 1 THEN '未读'
                                           ELSE '已读'
                                       END as status_text
                                FROM task_reminders r 
                                WHERE r.user_id = ?
                                ORDER BY r.remind_time DESC 
                                LIMIT 5
                            ");
                            $stmt->execute([$_SESSION['user_id']]);
                            $reminders = $stmt->fetchAll();

                            if (empty($reminders)): ?>
                                <tr>
                                    <td colspan="4" class="text-center">暂无提醒记录</td>
                                </tr>
                                <?php else:
                                foreach ($reminders as $reminder): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($reminder['title']); ?></td>
                                        <td><?php echo $reminder['type_text']; ?></td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($reminder['remind_time'])); ?></td>
                                        <td><?php echo $reminder['status_text']; ?></td>
                                    </tr>
                            <?php endforeach;
                            endif;
                        } catch (PDOException $e) { ?>
                            <tr>
                                <td colspan="4" class="text-center">获取提醒记录失败：<?php echo $e->getMessage(); ?></td>
                            </tr>
                        <?php } ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>