<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('task_team');

// 记录访问日志
record_log('访问团队协作页面');

// 添加/编辑团队处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加团队
    if ($_POST['action'] == 'add') {
        $team_name = isset($_POST['team_name']) ? trim($_POST['team_name']) : '';
        $department = isset($_POST['department']) ? trim($_POST['department']) : '';
        $members = isset($_POST['members']) ? $_POST['members'] : [];

        if (empty($team_name) || empty($department)) {
            $error = '请填写团队名称和所属部门！';
        } else {
            try {
                // 添加团队，当前用户为团队负责人
                $members_str = !empty($members) ? ',' . implode(',', $members) . ',' : '';
                $stmt = $pdo->prepare("INSERT INTO perf_teams (team_name, leader_id, members, department) VALUES (?, ?, ?, ?)");
                $result = $stmt->execute([$team_name, $_SESSION['user_id'], $members_str, $department]);

                if ($result) {
                    record_log("创建团队：{$team_name}");
                    $success = '团队创建成功！';
                    // 重定向到没有参数的页面
                    header('Location: team.php?success=add');
                    exit;
                } else {
                    $error = '团队创建失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑团队
    elseif ($_POST['action'] == 'edit') {
        $team_id = isset($_POST['team_id']) ? intval($_POST['team_id']) : 0;
        $team_name = isset($_POST['team_name']) ? trim($_POST['team_name']) : '';
        $department = isset($_POST['department']) ? trim($_POST['department']) : '';
        $members = isset($_POST['members']) ? $_POST['members'] : [];

        if ($team_id <= 0 || empty($team_name) || empty($department)) {
            $error = '请填写完整团队信息！';
        } else {
            try {
                // 验证当前用户是否为团队负责人
                $stmt = $pdo->prepare("SELECT leader_id FROM perf_teams WHERE id = ?");
                $stmt->execute([$team_id]);
                $team = $stmt->fetch();

                if (!$team || $team['leader_id'] != $_SESSION['user_id']) {
                    $error = '您没有权限编辑此团队！';
                } else {
                    // 更新团队信息
                    $members_str = !empty($members) ? ',' . implode(',', $members) . ',' : '';
                    $stmt = $pdo->prepare("UPDATE perf_teams SET team_name = ?, members = ?, department = ? WHERE id = ?");
                    $result = $stmt->execute([$team_name, $members_str, $department, $team_id]);

                    if ($result) {
                        record_log("编辑团队：{$team_name}");
                        $success = '团队信息更新成功！';
                        // 重定向到没有参数的页面
                        header('Location: team.php?success=edit');
                        exit;
                    } else {
                        $error = '团队信息更新失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除团队
    elseif ($_POST['action'] == 'delete') {
        $team_id = isset($_POST['team_id']) ? intval($_POST['team_id']) : 0;

        if ($team_id <= 0) {
            $error = '无效的团队ID！';
        } else {
            try {
                // 验证当前用户是否为团队负责人
                $stmt = $pdo->prepare("SELECT team_name, leader_id FROM perf_teams WHERE id = ?");
                $stmt->execute([$team_id]);
                $team = $stmt->fetch();

                if (!$team) {
                    $error = '团队不存在！';
                } elseif ($team['leader_id'] != $_SESSION['user_id']) {
                    $error = '您没有权限删除此团队！';
                } else {
                    // 检查是否有关联的团队任务
                    $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM task_todos WHERE team_id = ?");
                    $stmt->execute([$team_id]);
                    $task_count = $stmt->fetch();

                    if ($task_count['count'] > 0) {
                        $error = '该团队存在未完成的任务，无法删除！请先完成或移除所有任务。';
                    } else {
                        // 删除团队
                        $stmt = $pdo->prepare("DELETE FROM perf_teams WHERE id = ?");
                        $result = $stmt->execute([$team_id]);

                        if ($result) {
                            record_log("删除团队：{$team['team_name']}");
                            $success = '团队删除成功！';
                        } else {
                            $error = '团队删除失败！';
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 添加团队任务
    elseif ($_POST['action'] == 'add_task') {
        $team_id = isset($_POST['team_id']) ? intval($_POST['team_id']) : 0;
        $title = isset($_POST['title']) ? trim($_POST['title']) : '';
        $priority = isset($_POST['priority']) ? intval($_POST['priority']) : 2;
        $end_time = isset($_POST['end_time']) ? trim($_POST['end_time']) : '';

        if ($team_id <= 0 || empty($title)) {
            $error = '请填写完整任务信息！';
        } else {
            try {
                // 验证当前用户是否有权限添加任务（团队负责人或成员）
                $stmt = $pdo->prepare("SELECT leader_id, members FROM perf_teams WHERE id = ?");
                $stmt->execute([$team_id]);
                $team = $stmt->fetch();

                $is_member = false;
                if ($team) {
                    if ($team['leader_id'] == $_SESSION['user_id']) {
                        $is_member = true;
                    } elseif (strpos($team['members'], ',' . $_SESSION['user_id'] . ',') !== false) {
                        $is_member = true;
                    }
                }

                if (!$team || !$is_member) {
                    $error = '您没有权限为此团队添加任务！';
                } else {
                    // 添加团队任务
                    $stmt = $pdo->prepare("INSERT INTO task_todos (title, type, priority, status, end_time, user_id, team_id) VALUES (?, 2, ?, 1, ?, ?, ?)");
                    $result = $stmt->execute([$title, $priority, $end_time ?: null, $_SESSION['user_id'], $team_id]);

                    if ($result) {
                        record_log("添加团队任务：{$title}");
                        $success = '团队任务添加成功！';
                    } else {
                        $error = '团队任务添加失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取用户相关的团队列表
try {
    $stmt = $pdo->prepare("
        SELECT * FROM perf_teams 
        WHERE leader_id = ? OR members LIKE ? 
        ORDER BY create_time DESC
    ");
    $stmt->execute([$_SESSION['user_id'], '%,' . $_SESSION['user_id'] . ',%']);
    $teams = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取团队列表失败：' . $e->getMessage();
    $teams = [];
}

// 获取所有用户，用于选择团队成员
try {
    $stmt = $pdo->query("SELECT id, username, mobile FROM sys_users ORDER BY id");
    $users = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取用户列表失败：' . $e->getMessage();
    $users = [];
}

// 判断是否显示表单
$show_form = false;
$edit_team = null;

// 编辑团队时显示表单并获取团队信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM perf_teams WHERE id = ? AND leader_id = ?");
        $stmt->execute([$edit_id, $_SESSION['user_id']]);
        $edit_team = $stmt->fetch();
        if (!$edit_team) {
            $error = '团队不存在或您没有权限编辑！';
            $show_form = false;
        } else {
            // 将成员ID字符串转换为数组
            $edit_team['member_ids'] = [];
            if (!empty($edit_team['members'])) {
                $members = explode(',', trim($edit_team['members'], ','));
                $edit_team['member_ids'] = $members;
            }
        }
    } catch (PDOException $e) {
        $error = '获取团队信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 添加团队时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 查看团队详情
$view_team = null;
$team_members = [];
$team_tasks = [];

if (isset($_GET['action']) && $_GET['action'] == 'view' && isset($_GET['id'])) {
    $view_id = intval($_GET['id']);
    try {
        // 获取团队信息
        $stmt = $pdo->prepare("
            SELECT t.*, u.username as leader_name, u.mobile as leader_mobile
            FROM perf_teams t
            LEFT JOIN sys_users u ON t.leader_id = u.id
            WHERE t.id = ?
        ");
        $stmt->execute([$view_id]);
        $view_team = $stmt->fetch();

        if (!$view_team) {
            $error = '团队不存在！';
        } else {
            // 验证当前用户是否为团队成员或负责人
            $is_member = false;
            if ($view_team['leader_id'] == $_SESSION['user_id']) {
                $is_member = true;
            } elseif (strpos($view_team['members'], ',' . $_SESSION['user_id'] . ',') !== false) {
                $is_member = true;
            }

            if (!$is_member) {
                $error = '您不是此团队的成员，无法查看详情！';
                $view_team = null;
            } else {
                // 获取团队成员信息
                if (!empty($view_team['members'])) {
                    $member_ids = explode(',', trim($view_team['members'], ','));
                    if (!empty($member_ids)) {
                        $placeholders = implode(',', array_fill(0, count($member_ids), '?'));
                        $stmt = $pdo->prepare("SELECT id, username, mobile FROM sys_users WHERE id IN ({$placeholders})");
                        $stmt->execute($member_ids);
                        $team_members = $stmt->fetchAll();
                    }
                }

                // 获取团队任务列表
                $stmt = $pdo->prepare("
                    SELECT t.*, u.username as creator_name
                    FROM task_todos t
                    LEFT JOIN sys_users u ON t.user_id = u.id
                    WHERE t.team_id = ?
                    ORDER BY t.status ASC, t.priority DESC, t.end_time ASC
                ");
                $stmt->execute([$view_id]);
                $team_tasks = $stmt->fetchAll();
            }
        }
    } catch (PDOException $e) {
        $error = '获取团队详情失败：' . $e->getMessage();
    }
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '团队创建成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '团队信息更新成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>团队协作</h2>
            <div class="breadcrumb">
                <a href="index.php">任务与日程管理</a> &gt; 团队协作
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="team.php?action=add" class="btn btn-add">创建团队</a>
                <a href="team.php" class="btn btn-secondary">我的团队</a>
            </div>

            <?php if ($view_team): ?>
                <!-- 团队详情 -->
                <div class="info-box">
                    <h3><?php echo htmlspecialchars($view_team['team_name']); ?> - 团队详情</h3>
                    <table class="info-table">
                        <tr>
                            <td width="100">团队名称：</td>
                            <td><?php echo htmlspecialchars($view_team['team_name']); ?></td>
                        </tr>
                        <tr>
                            <td>所属部门：</td>
                            <td><?php echo htmlspecialchars($view_team['department']); ?></td>
                        </tr>
                        <tr>
                            <td>团队负责人：</td>
                            <td>
                                <?php
                                echo htmlspecialchars($view_team['leader_name']);
                                echo ($view_team['leader_id'] == $_SESSION['user_id']) ? ' (您)' : '';
                                ?>
                            </td>
                        </tr>
                        <tr>
                            <td>创建时间：</td>
                            <td><?php echo date('Y-m-d H:i', strtotime($view_team['create_time'])); ?></td>
                        </tr>
                    </table>
                </div>

                <!-- 团队成员列表 -->
                <div class="table-container">
                    <h3>团队成员</h3>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>用户ID</th>
                                <th>用户名</th>
                                <th>联系方式</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($team_members)): ?>
                                <tr>
                                    <td colspan="3" class="text-center">暂无其他团队成员</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($team_members as $member): ?>
                                    <tr>
                                        <td><?php echo $member['id']; ?></td>
                                        <td>
                                            <?php
                                            echo htmlspecialchars($member['username']);
                                            if ($member['mobile']): ?>
                                                (<?php echo htmlspecialchars($member['mobile']); ?>)
                                            <?php endif; ?>
                                            <?php echo ($member['id'] == $_SESSION['user_id']) ? ' (您)' : ''; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>

                <!-- 团队任务列表 -->
                <div class="table-container">
                    <h3>团队任务</h3>
                    <?php if ($view_team['leader_id'] == $_SESSION['user_id'] || strpos($view_team['members'], ',' . $_SESSION['user_id'] . ',') !== false): ?>
                        <div class="form-container">
                            <form method="post" action="">
                                <input type="hidden" name="action" value="add_task">
                                <input type="hidden" name="team_id" value="<?php echo $view_team['id']; ?>">
                                <div class="filter-row">
                                    <div class="filter-item">
                                        <input type="text" name="title" placeholder="任务标题" required>
                                    </div>
                                    <div class="filter-item">
                                        <select name="priority">
                                            <option value="3">高优先级</option>
                                            <option value="2" selected>中优先级</option>
                                            <option value="1">低优先级</option>
                                        </select>
                                    </div>
                                    <div class="filter-item">
                                        <input type="datetime-local" name="end_time" placeholder="截止时间">
                                    </div>
                                    <div class="filter-item">
                                        <button type="submit" class="btn btn-add">添加任务</button>
                                    </div>
                                </div>
                            </form>
                        </div>
                    <?php endif; ?>

                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>任务标题</th>
                                <th>优先级</th>
                                <th>截止时间</th>
                                <th>状态</th>
                                <th>创建人</th>
                                <th>创建时间</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($team_tasks)): ?>
                                <tr>
                                    <td colspan="7" class="text-center">暂无团队任务</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($team_tasks as $task): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($task['title']); ?></td>
                                        <td>
                                            <?php
                                            if ($task['priority'] == 3) echo '<span style="color: red;">高</span>';
                                            elseif ($task['priority'] == 2) echo '<span style="color: orange;">中</span>';
                                            else echo '<span style="color: green;">低</span>';
                                            ?>
                                        </td>
                                        <td>
                                            <?php
                                            if ($task['end_time']) {
                                                $end_time = strtotime($task['end_time']);
                                                $now = time();
                                                echo date('Y-m-d H:i', $end_time);

                                                // 如果任务未完成且快到期或已过期，显示提示
                                                if ($task['status'] == 1) {
                                                    if ($end_time < $now) {
                                                        echo ' <span style="color: red;">(已过期)</span>';
                                                    } elseif ($end_time - $now < 86400) {
                                                        echo ' <span style="color: orange;">(即将到期)</span>';
                                                    }
                                                }
                                            } else {
                                                echo '无截止时间';
                                            }
                                            ?>
                                        </td>
                                        <td>
                                            <?php
                                            if ($task['status'] == 1) {
                                                echo '<span style="color: #ffc107;">待处理</span>';
                                            } else {
                                                echo '<span style="color: #28a745;">已完成</span>';
                                            }
                                            ?>
                                        </td>
                                        <td><?php echo htmlspecialchars($task['creator_name']); ?></td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($task['create_time'])); ?></td>
                                        <td>
                                            <a href="todo.php?action=edit&id=<?php echo $task['id']; ?>" class="btn btn-sm btn-edit">查看详情</a>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>

                <div class="action-bar">
                    <a href="team.php" class="btn btn-secondary">返回团队列表</a>
                    <?php if ($view_team['leader_id'] == $_SESSION['user_id']): ?>
                        <a href="team.php?action=edit&id=<?php echo $view_team['id']; ?>" class="btn btn-edit">编辑团队</a>
                    <?php endif; ?>
                </div>
            <?php elseif ($show_form): ?>
                <!-- 添加/编辑团队表单 -->
                <div class="form-container">
                    <h3><?php echo $edit_team ? '编辑团队' : '创建团队'; ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_team ? 'edit' : 'add'; ?>">
                        <?php if ($edit_team): ?>
                            <input type="hidden" name="team_id" value="<?php echo $edit_team['id']; ?>">
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="team_name">团队名称：</label>
                            <input type="text" id="team_name" name="team_name" value="<?php echo $edit_team ? htmlspecialchars($edit_team['team_name']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="department">所属部门：</label>
                            <input type="text" id="department" name="department" value="<?php echo $edit_team ? htmlspecialchars($edit_team['department']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="members">选择团队成员：</label>
                            <div class="options-container">
                                <?php foreach ($users as $user): ?>
                                    <?php if ($user['id'] != $_SESSION['user_id']): ?>
                                        <div class="checkbox-item">
                                            <label>
                                                <input type="checkbox" name="members[]" value="<?php echo $user['id']; ?>"
                                                    <?php echo ($edit_team && in_array($user['id'], $edit_team['member_ids'])) ? 'checked' : ''; ?>>
                                                <?php echo htmlspecialchars($user['username']); ?>
                                                <?php if ($user['mobile']): ?>
                                                    (<?php echo htmlspecialchars($user['mobile']); ?>)
                                                <?php endif; ?>
                                            </label>
                                        </div>
                                    <?php endif; ?>
                                <?php endforeach; ?>
                            </div>
                            <p class="help-text">注意：您（<?php echo $_SESSION['username']; ?>）将自动成为团队负责人，无需在此选择。</p>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="team.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php else: ?>
                <!-- 团队列表 -->
                <div class="table-container">
                    <h3>我的团队</h3>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>团队名称</th>
                                <th>所属部门</th>
                                <th>我的角色</th>
                                <th>成员数量</th>
                                <th>创建时间</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($teams)): ?>
                                <tr>
                                    <td colspan="7" class="text-center">暂无团队数据</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($teams as $team): ?>
                                    <tr>
                                        <td><?php echo $team['id']; ?></td>
                                        <td><?php echo htmlspecialchars($team['team_name']); ?></td>
                                        <td><?php echo htmlspecialchars($team['department']); ?></td>
                                        <td>
                                            <?php
                                            if ($team['leader_id'] == $_SESSION['user_id']) {
                                                echo '<span style="color: #28a745;">负责人</span>';
                                            } else {
                                                echo '<span style="color: #007bff;">成员</span>';
                                            }
                                            ?>
                                        </td>
                                        <td>
                                            <?php
                                            $member_count = 0;
                                            if (!empty($team['members'])) {
                                                $members = explode(',', trim($team['members'], ','));
                                                $member_count = count($members);
                                            }
                                            echo $member_count;
                                            ?>
                                        </td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($team['create_time'])); ?></td>
                                        <td>
                                            <a href="team.php?action=view&id=<?php echo $team['id']; ?>" class="btn btn-sm btn-primary">查看详情</a>
                                            <?php if ($team['leader_id'] == $_SESSION['user_id']): ?>
                                                <a href="team.php?action=edit&id=<?php echo $team['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                                <form method="post" action="" style="display:inline;">
                                                    <input type="hidden" name="action" value="delete">
                                                    <input type="hidden" name="team_id" value="<?php echo $team['id']; ?>">
                                                    <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除团队 \'<?php echo htmlspecialchars($team['team_name']); ?>\' 吗？所有团队任务也将被删除。');">删除</button>
                                                </form>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>

            <!-- 提示信息 -->
            <div class="info-box">
                <h3>关于团队协作</h3>
                <p>团队协作功能帮助您：</p>
                <ul>
                    <li><strong>创建团队</strong>：您可以创建团队并邀请其他用户加入。</li>
                    <li><strong>团队任务</strong>：为团队分配任务，所有团队成员均可查看和管理团队任务。</li>
                    <li><strong>任务跟踪</strong>：实时了解团队任务的进展情况。</li>
                    <li><strong>成员管理</strong>：作为团队负责人，您可以添加或移除团队成员。</li>
                </ul>
                <p>提示：有效的团队协作能够提高工作效率，确保项目顺利完成。</p>
            </div>
        </div>
    </div>
</body>

</html>